<?xml version="1.0" encoding="ISO-8859-1"?>

<xsl:stylesheet
    xmlns:xsl = "http://www.w3.org/1999/XSL/Transform"
    version = "1.0">

 <!-- those 2 must be passed with "- -stringparam name value" from xsltproc -->
 <xsl:param name="strictfgfs"/>
 <xsl:param name="lang"/>

 <xsl:preserve-space elements="freetext"/>

 <xsl:variable name="NM2KM" select="1.852"/>
 <xsl:variable name="FT2M" select="0.3048"/>
 <xsl:variable name="SM2M" select="1609.3412196"/> <!-- statute mile! -->
 <xsl:variable name="METER_PER_SEC2KT" select="3.6 div $NM2KM"/>
 <xsl:variable name="INHG2HPA" select="33.86388640341"/>

 <xsl:template match="data">
  <xsl:if test="$method = 'html'">
   <xsl:comment> start of data </xsl:comment>
   <xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:choose>
   <xsl:when test="$lang = 'en'">
    <xsl:apply-templates select="metafList/taf|metafList/metar">
     <xsl:with-param name="trans" select="document('metaf-lang.xsl')//trans/en"/>
    </xsl:apply-templates>
   </xsl:when>
   <xsl:when test="$lang = 'es'">
    <xsl:apply-templates select="metafList/taf|metafList/metar">
     <xsl:with-param name="trans" select="document('metaf-lang.xsl')//trans/es"/>
    </xsl:apply-templates>
   </xsl:when>
   <xsl:otherwise>
    <xsl:apply-templates select="metafList/taf|metafList/metar">
     <xsl:with-param name="trans" select="document('metaf-lang.xsl')//trans/de"/>
    </xsl:apply-templates>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:if test="$method = 'html'">
   <xsl:comment> metaf: $Id: metaf.xsl,v 1.22 2006/08/18 10:06:48 metaf2xml Exp $ </xsl:comment>
   <xsl:text>&#10;</xsl:text>
   <xsl:comment>
   <xsl:value-of select="concat(' metaf-lang: ', document('metaf-lang.xsl')//trans/version, ' ')"/>
   </xsl:comment>
   <xsl:text>&#10;</xsl:text>
   <xsl:apply-templates select="versionList/version"/>
   <xsl:comment> end of data </xsl:comment>
  </xsl:if>
 </xsl:template>

 <xsl:template match="version">
  <xsl:comment><xsl:value-of select="concat(' ', ., ' ')"/></xsl:comment>
  <xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="taf">
  <xsl:param name="trans"/>
  <table border="1" cellpadding="2">
  <tr>
  <td colspan="4" style="font-family: monospace; font-size: 90%;">
  <xsl:value-of select="concat('msg: ', @s)"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:apply-templates select="WARNING">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <tr>
   <xsl:if test="$method = 'html'">
    <td><b>TAF</b></td>
   </xsl:if>
   <th nowrap="1" colspan="3">
    <xsl:value-of select="$trans/hdr[@o='taf']"/>
    <xsl:apply-templates select="reportModifier">
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:apply-templates>
    <xsl:if test="$method != 'html'">
     <xsl:value-of select="concat('&#10;', $trans/hdr[@o='taf_ul'])"/>
    </xsl:if>
   </th>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:apply-templates select="obsStation">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="issueTime">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="fcstPeriod">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="sfcWind">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="CAVOK">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="visPrev">
   <xsl:with-param name="unitThreshold" select="1000"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="weatherList">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="cloudList">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="visVert">
   <xsl:with-param name="unitThreshold" select="1000"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="tempMax|tempMin">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="tempAtList/tempAt">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="windShearLvl|turbulence|icing">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="amendment">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="trendList">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="remarkList">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:if test="ERROR/descr/@v != ''">
   <xsl:choose>
    <xsl:when test="$method = 'html'">
     <xsl:apply-templates select="ERROR">
      <xsl:with-param name="trans" select="$trans"/>
     </xsl:apply-templates>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="concat('ERROR: invalid format: ', ERROR/pos/@v, '&#10;')"/>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:if>
  </table>
  <xsl:text>&#10;</xsl:text>
  <xsl:if test="position()!=last()"><br /></xsl:if>
 </xsl:template>

 <xsl:template match="metar">
  <xsl:param name="trans"/>
  <table border="1" cellpadding="2">
  <tr>
  <td colspan="4" style="font-family: monospace; font-size: 90%;">
  <xsl:value-of select="concat('msg: ', @s)"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="$strictfgfs != 1">
   <xsl:apply-templates select="WARNING">
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:apply-templates>
  </xsl:if>
  <tr>
   <xsl:choose>
    <xsl:when test="SPECI/@v != ''">
     <xsl:if test="$method = 'html'">
      <td><b>SPECI</b></td>
     </xsl:if>
     <th nowrap="1" colspan="3">
      <xsl:value-of select="$trans/hdr[@o='speci']"/>
      <xsl:apply-templates select="reportModifier">
       <xsl:with-param name="trans" select="$trans"/>
      </xsl:apply-templates>
      <xsl:if test="$method != 'html'">
       <xsl:value-of select="concat('&#10;', $trans/hdr[@o='speci_ul'])"/>
      </xsl:if>
     </th>
    </xsl:when>
    <xsl:otherwise>
     <xsl:if test="$method = 'html'">
      <td><b>METAR</b></td>
     </xsl:if>
     <th nowrap="1" colspan="3">
      <xsl:value-of select="$trans/hdr[@o='metar']"/>
      <xsl:apply-templates select="reportModifier">
       <xsl:with-param name="trans" select="$trans"/>
      </xsl:apply-templates>
      <xsl:if test="$method != 'html'">
       <xsl:value-of select="concat('&#10;', $trans/hdr[@o='metar_ul'])"/>
      </xsl:if>
     </th>
    </xsl:otherwise>
   </xsl:choose>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:apply-templates select="obsStation">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="obsTime">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="sfcWind">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:if test="$strictfgfs != 1">
   <xsl:apply-templates select="CAVOK">
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:apply-templates>
  </xsl:if>
  <xsl:apply-templates select="visPrev">
   <xsl:with-param name="unitThreshold" select="1000"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="visRwyList/visRwy">
   <xsl:with-param name="unitThreshold" select="1000"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="RVRNO">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="weatherList">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="cloudList">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="visVert">
   <xsl:with-param name="unitThreshold" select="1000"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="temperature">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="QNH">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="windShearList/windShear">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="rwyStateList/rwyState">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:if test="$strictfgfs = 1">
   <xsl:apply-templates select="remarkRwyState">
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:apply-templates>
  </xsl:if>
  <xsl:if test="$strictfgfs != 1">
   <xsl:if test="somePressure/@s != ''">
    <xsl:apply-templates select="somePressure">
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:apply-templates>
   </xsl:if>
   <xsl:apply-templates select="recentWeatherList">
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:apply-templates>
   <xsl:apply-templates select="colourCode">
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:apply-templates>
   <xsl:apply-templates select="cloudMaxCover">
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:apply-templates>
   <xsl:apply-templates select="trendList">
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:apply-templates>
   <xsl:apply-templates select="remarkList">
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:apply-templates>
  </xsl:if>
  <xsl:if test="ERROR/descr/@v != ''">
   <xsl:choose>
    <xsl:when test="$method = 'html'">
     <xsl:apply-templates select="ERROR">
      <xsl:with-param name="trans" select="$trans"/>
     </xsl:apply-templates>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="concat('ERROR: invalid format: ', ERROR/pos/@v, '&#10;')"/>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:if>
  </table>
  <xsl:text>&#10;</xsl:text>
  <xsl:if test="position()!=last()"><br /></xsl:if>
 </xsl:template>

 <xsl:template match="reportModifier">
  <xsl:param name="trans"/>
  <xsl:text>&#9;&#9;(</xsl:text>
  <xsl:variable name="this" select="."/>
  <xsl:value-of select="$trans/reportModifierType[@o=$this/modifierType/@v]"/>
  <xsl:if test="type/@v = 'P'">
    <xsl:if test="isLastSegment/@v = '1'">
     <xsl:value-of select="concat($trans/t[@o='last'],' ')"/>
    </xsl:if>
   <xsl:value-of select="concat($trans/t[@o='segment'],' ')"/>
   <xsl:value-of select="segment/@v"/>
  </xsl:if>
  <xsl:if test="over24hLate/@v = '1'">
   <xsl:text>, bulletin over 24 hours after observation</xsl:text>
  </xsl:if>
  <xsl:if test="sequenceLost/@v = '1'">
   <xsl:text>, bulletin sequence lost</xsl:text>
  </xsl:if>
  <xsl:if test="bulletinSeq/@v != ''">
   <xsl:text>, bulletin sequence </xsl:text>
   <xsl:value-of select="bulletinSeq/@v"/>
  </xsl:if>
  <xsl:text>)</xsl:text>
 </xsl:template>

 <xsl:template match="obsStation">
  <xsl:param name="trans"/>
  <tr>
   <xsl:if test="$method = 'html'">
    <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
   </xsl:if>
   <td nowrap="1">
   <xsl:value-of select="$trans/hdr[@o='obsStation']"/>
   </td>
   <td nowrap="1" colspan="2"><xsl:value-of select="id/@v"/></td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="fcstPeriod">
  <xsl:param name="trans"/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='fcstPeriod']"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:choose>
   <xsl:when test="invalidFormat/@v != ''">
    <xsl:value-of select="concat('(', $trans/t[@o='invalidFormat'])"/>
    <xsl:text>: '</xsl:text>
    <xsl:value-of select="invalidFormat/@v"/>
    <xsl:text>')</xsl:text>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="concat(format-number(day/@v, '0'), '., ', hourFrom/@v, ':00 - ', hourTill/@v, ':00 UTC')"/>
    <xsl:if test="hourFrom/@v &gt;= hourTill/@v">
     <xsl:value-of select="$trans/t[@o='nextDay']"/>
    </xsl:if>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="obsTime|issueTime">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
   <xsl:if test="$method = 'html'">
    <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
   </xsl:if>
   <td nowrap="1">
   <xsl:value-of select="$trans/hdr[@o=name($this)]"/>
   </td>
   <td nowrap="1" colspan="2">
    <xsl:choose>
     <xsl:when test="invalidFormat/@v != ''">
      <xsl:value-of select="concat('(', $trans/t[@o='invalidFormat'])"/>
      <xsl:text>: '</xsl:text>
      <xsl:value-of select="invalidFormat/@v"/>
      <xsl:text>')</xsl:text>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="substring-before($trans/t[@o='onThe'], '|')"/>
      <xsl:value-of select="format-number(day/@v, '0')"/>
      <xsl:value-of select="substring-after($trans/t[@o='onThe'], '|')"/>
      <xsl:value-of select="concat(format-number(hour/@v, '00'), ':')"/>
      <xsl:value-of select="concat(format-number(minute/@v, '00'), ' UTC')"/>
     </xsl:otherwise>
    </xsl:choose>
   </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="visPrev">
  <xsl:param name="unitThreshold"/>
  <xsl:param name="trans"/>
  <xsl:variable name="rows">
   <xsl:choose>
    <xsl:when test="NDV/@v = '1' and ../visMin != ''">3</xsl:when>
    <xsl:when test="NDV/@v = '1' or  ../visMin != ''">2</xsl:when>
    <xsl:otherwise>1</xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <xsl:variable name="str">
   <xsl:choose>
    <xsl:when test="../visMin != ''">
     <xsl:value-of select="concat(@s, ' ', ../visMin/@s)"/>
    </xsl:when>
    <xsl:otherwise><xsl:value-of select="@s"/></xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <tr>
  <xsl:call-template name="visibility_str">
   <xsl:with-param name="str" select="$str"/>
   <xsl:with-param name="rows" select="$rows"/>
  </xsl:call-template>
  <xsl:call-template name="visibility_header">
   <xsl:with-param name="header" select="$trans/hdr[@o='visPrev']"/>
   <xsl:with-param name="rows" select="$rows"/>
  </xsl:call-template>
  <xsl:call-template name="visibility">
   <xsl:with-param name="notavail" select="$trans/t[@o='notAvailable']"/>
   <xsl:with-param name="rnd_m" select="50"/>
   <xsl:with-param name="unitThreshold" select="$unitThreshold"/>
   <xsl:with-param name="visVal" select="."/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="NDV/@v != ''">
   <tr><td nowrap="1" colspan="2">
   <xsl:text>&#9;&#9;&#9;</xsl:text>
   <xsl:text>(No Directional Variation reporting capabilty)</xsl:text>
   </td></tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="../visMin != ''">
   <tr>
   <xsl:text>&#9;&#9;&#9;</xsl:text>
   <xsl:call-template name="visibility">
    <xsl:with-param name="notavail" select="$trans/t[@o='notAvailable']"/>
    <xsl:with-param name="rnd_m" select="50"/>
    <xsl:with-param name="unitThreshold" select="$unitThreshold"/>
    <xsl:with-param name="visVal" select="../visMin"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="visVert">
  <xsl:param name="unitThreshold"/>
  <xsl:param name="trans"/>
  <tr>
  <xsl:call-template name="visibility_str">
   <xsl:with-param name="str" select="@s"/>
   <xsl:with-param name="rows" select="1"/>
  </xsl:call-template>
  <xsl:call-template name="visibility_header">
   <xsl:with-param name="header" select="$trans/hdr[@o='visVert']"/>
   <xsl:with-param name="rows" select="1"/>
  </xsl:call-template>
  <xsl:call-template name="visibility">
   <xsl:with-param name="notavail" select="$trans/t[@o='visVertNA']"/>
   <xsl:with-param name="rnd_m" select="30"/>
   <xsl:with-param name="unitThreshold" select="$unitThreshold"/>
   <xsl:with-param name="visVal" select="."/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="visRwy">
  <xsl:param name="unitThreshold"/>
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:variable name="hdr" select="$trans/hdr[@o='visRwy']"/>
  <xsl:variable name="rows">
   <xsl:choose>
    <xsl:when test="RVRVariations != '' and visTrend/@v !=''">3</xsl:when>
    <xsl:when test="RVRVariations != '' or  visTrend/@v !=''">2</xsl:when>
    <xsl:otherwise>1</xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <tr>
  <xsl:call-template name="visibility_str">
   <xsl:with-param name="str" select="@s"/>
   <xsl:with-param name="rows" select="$rows"/>
  </xsl:call-template>
  <xsl:call-template name="visibility_header">
   <xsl:with-param name="header" select="concat(substring-before($hdr, '|'), rwyDesig/@v, substring-after($hdr, '|'))"/>
   <xsl:with-param name="rows" select="$rows"/>
  </xsl:call-template>
  <xsl:call-template name="visibility">
   <xsl:with-param name="notavail" select="$trans/t[@o='rwyVisNotAvailable']"/>
   <xsl:with-param name="rnd_m" select="25"/>
   <xsl:with-param name="unitThreshold" select="$unitThreshold"/>
   <xsl:with-param name="visVal" select="RVR"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="RVRVariations != ''">
   <xsl:text>&#9;&#9;&#9;</xsl:text>
   <tr>
   <xsl:call-template name="visibility">
    <xsl:with-param name="notavail" select="$trans/t[@o='rwyVisNotAvailable']"/>
    <xsl:with-param name="rnd_m" select="25"/>
    <xsl:with-param name="unitThreshold" select="$unitThreshold"/>
    <xsl:with-param name="visVal" select="RVRVariations"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="visTrend/@v != '' and $strictfgfs != 1">
   <tr>
   <td nowrap="1" colspan="2">
    <xsl:value-of select="concat($trans/hdr[@o='visTrend'], $trans/visTrend[@o=$this/visTrend/@v])"/>
   </td></tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="(RVRVariations != '' or (visTrend/@v != '' and $strictfgfs != 1))"><xsl:text>&#10;</xsl:text></xsl:if>
 </xsl:template>

 <xsl:template name="visibility_str">
  <xsl:param name="rows"/>
  <xsl:param name="str"/>
  <xsl:if test="$method = 'html'">
   <xsl:element name="td">
    <xsl:attribute name="nowrap">1</xsl:attribute>
    <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
    <b><xsl:value-of select="$str"/></b>
   </xsl:element>
  </xsl:if>
 </xsl:template>

 <xsl:template name="visibility_header">
  <xsl:param name="header"/>
  <xsl:param name="rows"/>
  <xsl:element name="td">
   <xsl:attribute name="nowrap">1</xsl:attribute>
   <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
   <xsl:value-of select="$header"/>
  </xsl:element>
 </xsl:template>

 <xsl:template name="visibility">
  <xsl:param name="notavail"/>
  <xsl:param name="rnd_m"/>
  <xsl:param name="unitThreshold"/>
  <xsl:param name="visVal"/>
  <xsl:param name="trans"/>
  <xsl:choose>
   <xsl:when test="$visVal/invalidFormat/@v != ''">
    <td nowrap="1" colspan="2">
    <xsl:value-of select="concat('(', $trans/t[@o='invalidFormat'])"/>
    <xsl:text>: '</xsl:text>
    <xsl:value-of select="$visVal/invalidFormat/@v"/>
    <xsl:text>')</xsl:text>
    </td>
   </xsl:when>
   <xsl:when test="$visVal/notAvailable/@v != ''">
    <td nowrap="1" colspan="2">
    <xsl:value-of select="$notavail"/>
    </td>
   </xsl:when>
   <xsl:otherwise>
    <xsl:variable name="lt_gt">
     <xsl:choose>
      <xsl:when test="$visVal/isLess/@v != ''">
       <xsl:text>&lt;</xsl:text>
      </xsl:when>
      <xsl:when test="$visVal/isGreater/@v != ''">
       <xsl:text>&gt;</xsl:text>
      </xsl:when>
      <xsl:when test="$visVal/isEqualGreater/@v != ''">
       <xsl:text>&gt;=</xsl:text>
      </xsl:when>
      <xsl:otherwise></xsl:otherwise>
     </xsl:choose>
    </xsl:variable>
    <xsl:variable name="vis">
     <xsl:choose>
      <xsl:when test="$visVal/unitLength/@v = 'M'">
       <xsl:choose>
        <xsl:when test="$visVal/distance/@v = 0">&lt;|50</xsl:when>
        <xsl:when test="$visVal/distance/@v = 9999">&gt;=|10000</xsl:when>
        <xsl:otherwise>
        <xsl:value-of select="concat($lt_gt, '|', $visVal/distance/@v)"/>
        </xsl:otherwise>
       </xsl:choose>
      </xsl:when>
      <xsl:when test="$visVal/unitLength/@v = 'KM'">
       <xsl:text>|</xsl:text><xsl:value-of select="$visVal/distance/@v * 1000"/>
      </xsl:when>
      <xsl:when test="$visVal/unitLength/@v = 'SM'">
       <xsl:value-of select="concat($lt_gt, '|', $visVal/distance/@v * $SM2M)"/>
      </xsl:when>
      <xsl:when test="$visVal/unitLength/@v = 'FT'">
       <xsl:value-of select="concat($lt_gt, '|', $visVal/distance/@v * $FT2M)"/>
      </xsl:when>
      <xsl:when test="$visVal/unitHeight/@v = 'FL'">
       <xsl:value-of select="concat($lt_gt, '|', $visVal/distance/@v * 100 * $FT2M)"/>
      </xsl:when>
     </xsl:choose>
    </xsl:variable>
    <xsl:call-template name="printVis">
     <xsl:with-param name="vis" select="$vis"/>
     <xsl:with-param name="compassDir" select="$visVal/compassDir/@v"/>
     <xsl:with-param name="rnd_m" select="$rnd_m"/>
     <xsl:with-param name="unitThreshold" select="$unitThreshold"/>
    </xsl:call-template>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template name="printVis">
  <xsl:param name="vis"/>
  <xsl:param name="compassDir"/>
  <xsl:param name="rnd_m"/>
  <xsl:param name="unitThreshold"/>
  <xsl:variable name="amountMeter" select="substring-after($vis, '|')"/>
  <xsl:variable name="lt_gt" select="substring-before($vis, '|')"/>
  <td nowrap="1">
  <xsl:value-of select="$lt_gt"/>
  <xsl:choose>
   <xsl:when test="$amountMeter &gt;= $unitThreshold">
    <xsl:value-of select="format-number($amountMeter div 1000,'0.#')"/>
    <xsl:text> km</xsl:text>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="format-number($amountMeter div $rnd_m ,'#0') * $rnd_m"/>
    <xsl:text> m</xsl:text>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:if test="$compassDir != ''">
    <xsl:value-of select="concat(' ', $compassDir)"/>
  </xsl:if>
  </td><xsl:text>&#9;&#9;&#9;&#9;&#9;</xsl:text><td nowrap="1">
  <xsl:value-of select="$lt_gt"/>
  <xsl:value-of select="format-number($amountMeter div $SM2M,'0.#')"/>
  <xsl:text> US-miles</xsl:text>
  <xsl:if test="$compassDir != ''">
   <xsl:value-of select="concat(' ', $compassDir)"/>
  </xsl:if>
  </td>
 </xsl:template>

 <xsl:template name="printTime">
  <xsl:param name="time"/>
  <xsl:param name="trans"/>
  <xsl:value-of select="substring-before($trans/t[@o='time-at'], '|')"/>
  <xsl:choose>
   <xsl:when test="$time/hour/@v != ''">
    <xsl:value-of select="concat(format-number($time/hour/@v, '00'), ':', format-number($time/minute/@v, '00 UTC'))"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="concat(substring-before($trans/t[@o='afterHour'], '|'), format-number($time/minute/@v, '0'), substring-after($trans/t[@o='afterHour'], '|'))"/>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:value-of select="substring-after($trans/t[@o='time-at'], '|')"/>
 </xsl:template>

 <xsl:template match="peakWind">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:variable name="hdr">
   <xsl:value-of select="substring-before($trans/hdr[@o='peakWind'], '|')"/>
   <xsl:call-template name="printTime">
    <xsl:with-param name="time"  select="."/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   <xsl:value-of select="substring-after($trans/hdr[@o='peakWind'], '|')"/>
  </xsl:variable>
  <xsl:apply-templates select="wind">
   <xsl:with-param name="hdr"   select="$hdr"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="rwyWind|thrWind">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:apply-templates select="wind">
   <xsl:with-param name="hdr"   select="concat(substring-before($trans/hdr[@o=name($this)], '|'), rwyDesig/@v, substring-after($trans/hdr[@o=name($this)], '|'))"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="sfcWind|gridWind">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:apply-templates select="wind">
   <xsl:with-param name="hdr"   select="$trans/hdr[@o=name($this)]"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="wind">
  <xsl:param name="hdr"/>
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:variable name="rows">
   <xsl:choose>
    <xsl:when test="gustSpeed/@v != '' and windVarLeft/@v != ''">3</xsl:when>
    <xsl:when test="gustSpeed/@v != '' or windVarLeft/@v != ''">2</xsl:when>
    <xsl:otherwise>1</xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <tr>
   <xsl:if test="$method = 'html'">
    <xsl:element name="td">
     <xsl:attribute name="nowrap">1</xsl:attribute>
     <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
     <b><xsl:value-of select="../@s"/></b>
    </xsl:element>
   </xsl:if>
   <xsl:element name="td">
    <xsl:attribute name="nowrap">1</xsl:attribute>
    <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
    <xsl:value-of select="$hdr"/>
   </xsl:element>
   <xsl:choose>
    <xsl:when test="invalidFormat/@v != ''">
     <td nowrap="1" colspan="2">
     <xsl:text>(invalid format: '</xsl:text>
     <xsl:value-of select="invalidFormat/@v"/>
     <xsl:text>')</xsl:text>
     </td>
    </xsl:when>
    <xsl:when test="notAvailable/@v != ''">
     <td nowrap="1" colspan="2">
     <xsl:value-of select="$trans/t[@o='notAvailable']"/>
     </td>
    </xsl:when>
    <xsl:when test="dir/@v = '0' and speed/@v = '0' and not(gustSpeed/@v !='')">
     <td nowrap="1" colspan="2">
     <xsl:value-of select="$trans/t[@o='calm']"/>
     </td>
    </xsl:when>
    <xsl:otherwise>
     <xsl:variable name="dir">
      <xsl:choose>
       <xsl:when test="dirNotAvailable/@v != ''">
        <xsl:value-of select="$trans/t[@o='dirNotAvailable']"/>
       </xsl:when>
       <xsl:when test="dirVariable/@v != ''">
        <xsl:value-of select="$trans/t[@o='dirVariable']"/>
       </xsl:when>
       <xsl:otherwise>
        <xsl:value-of select="concat($trans/t[@o='wind-from'],' ')"/>
        <xsl:value-of select="$trans/compassDir16/arr[position()=1+format-number($this/dir/@v div 45 * 2, '0')]"/>
        <xsl:value-of select="concat(' (', dir/@v, ')')"/>
       </xsl:otherwise>
      </xsl:choose>
     </xsl:variable>
     <xsl:choose>
      <xsl:when test="speedNotAvailable/@v != ''">
       <td nowrap="1" colspan="2">
       <xsl:value-of select="$dir"/>
       <xsl:if test="not(dirNotAvailable/@v != '')">
        <xsl:text>,</xsl:text>
       </xsl:if>
       <xsl:value-of select="$trans/t[@o='speedNotAvailable']"/>
       </td>
      </xsl:when>
      <xsl:otherwise>
       <xsl:variable name="speed">
        <xsl:call-template name="speed2kt">
         <xsl:with-param name="speed" select="speed/@v"/>
         <xsl:with-param name="unit" select="unitSpeed/@v"/>
        </xsl:call-template>
       </xsl:variable>
       <xsl:call-template name="printSpeed">
        <xsl:with-param name="dir" select="$dir"/>
        <xsl:with-param name="speed" select="$speed"/>
        <xsl:with-param name="delim" select="'&#9;&#9;'"/>
        <xsl:with-param name="greater" select="speedGreater/@v"/>
        <xsl:with-param name="trans" select="$trans"/>
       </xsl:call-template>
      </xsl:otherwise>
     </xsl:choose>
    </xsl:otherwise>
   </xsl:choose>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="gustSpeed/@v != ''">
   <tr>
   <xsl:variable name="gustSpeed">
    <xsl:call-template name="speed2kt">
     <xsl:with-param name="speed" select="gustSpeed/@v"/>
     <xsl:with-param name="unit" select="unitSpeed/@v"/>
    </xsl:call-template>
   </xsl:variable>
   <xsl:call-template name="printSpeed">
    <xsl:with-param name="dir" select="$trans/t[@o='wind-gusts']"/>
    <xsl:with-param name="speed" select="$gustSpeed"/>
    <xsl:with-param name="delim" select="'&#9;&#9;&#9;'"/>
    <xsl:with-param name="greater" select="gustSpeedGreater/@v"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="windVarLeft/@v != ''">
   <tr>
   <td nowrap="1" colspan="2">
   <xsl:value-of select="concat($trans/t[@o='variable'], ' ')"/>
   <xsl:value-of select="concat($trans/t[@o='variable-from'],' ')"/>
   <xsl:value-of select="concat($trans/compassDir16/arr[position()=1+format-number($this/windVarLeft/@v div 45 * 2, '0')], ' ')"/>
   <xsl:value-of select="concat($trans/t[@o='variable-to'], ' ')"/>
   <xsl:value-of select="concat($trans/compassDir16/arr[position()=1+format-number($this/windVarRight/@v div 45 * 2, '0')], ' ')"/>
   <xsl:value-of select="concat('(', windVarLeft/@v, '--', windVarRight/@v, ')')"/>
   </td></tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template name="printSpeed">
  <xsl:param name="dir"/>
  <xsl:param name="speed"/>
  <xsl:param name="delim"/>
  <xsl:param name="greater"/>
  <xsl:param name="trans"/>
  <xsl:variable name="gt">
   <xsl:if test="$greater != ''">&gt;</xsl:if>
  </xsl:variable>
  <td nowrap="1">
  <xsl:value-of select="$dir"/>
  <xsl:value-of select="concat(' ', $trans/t[@o='wind-at'], ' ', $gt)"/>
  <xsl:value-of select="format-number($speed * $NM2KM, '0.#')"/>
  <xsl:text> km/h</xsl:text>
  </td>
  <xsl:value-of select="$delim"/>
  <td nowrap="1">
  <xsl:value-of select="$gt"/>
  <xsl:value-of select="format-number($speed, '0.#')"/>
  <xsl:value-of select="concat(' kt = ', $gt)"/>
  <xsl:value-of select="format-number($speed * $NM2KM div $SM2M * 1000,'0.#')"/>
  <xsl:value-of select="concat(' mph = ', $gt)"/>
  <xsl:value-of select="format-number($speed * $NM2KM div 3.6, '0.# m/s')"/>
  </td>
 </xsl:template>

 <xsl:template name="speed2kt">
  <xsl:param name="speed"/>
  <xsl:param name="unit"/>
  <xsl:choose>
   <xsl:when test="$unit = 'KT'">
    <xsl:value-of select="$speed"/>
   </xsl:when>
   <xsl:when test="$unit = 'KMH'">
    <xsl:value-of select="$speed div $NM2KM"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$speed * $METER_PER_SEC2KT"/>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="weatherList">
  <xsl:param name="trans"/>
  <xsl:variable name="s_list">
   <xsl:apply-templates select="weather" mode="list"/>
  </xsl:variable>
  <xsl:apply-templates select="weather">
   <xsl:with-param name="s_list" select="$s_list"/>
   <xsl:with-param name="hdr1" select="$trans/hdr[@o='weather-1']"/>
   <xsl:with-param name="is_recent" select="0"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="weather" mode="list">
  <xsl:value-of select="concat(' ', @s)"/>
 </xsl:template>

 <xsl:template match="weather">
  <xsl:param name="s_list"/>
  <xsl:param name="hdr1"/>
  <xsl:param name="is_recent"/>
  <xsl:param name="trans"/>
  <xsl:choose>
   <xsl:when test="position() = 1">
    <tr>
    <xsl:if test="$method = 'html'">
     <xsl:element name="td">
      <xsl:attribute name="nowrap">1</xsl:attribute>
      <xsl:attribute name="rowspan"><xsl:value-of select="last()"/></xsl:attribute>
      <b><xsl:value-of select="$s_list"/></b>
     </xsl:element>
    </xsl:if>
    <xsl:element name="td">
     <xsl:attribute name="nowrap">1</xsl:attribute>
     <xsl:attribute name="rowspan"><xsl:value-of select="last()"/></xsl:attribute>
     <xsl:value-of select="$hdr1"/>
    </xsl:element>
    <td nowrap="1" colspan="2">
    <xsl:call-template name="printWeather">
     <xsl:with-param name="is_recent" select="$is_recent"/>
     <xsl:with-param name="this" select="."/>
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:call-template>
    </td></tr>
   </xsl:when>
   <xsl:otherwise>
    <tr><td nowrap="1" colspan="2">
    <xsl:if test="$method = 'text'">, </xsl:if>
    <xsl:call-template name="printWeather">
     <xsl:with-param name="is_recent" select="$is_recent"/>
     <xsl:with-param name="this" select="."/>
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:call-template>
    </td></tr>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template name="printWeather">
  <xsl:param name="is_recent"/>
  <xsl:param name="this"/>
  <xsl:param name="trans"/>
  <xsl:choose>
   <xsl:when test="$this/notAvailable/@v != ''">
     <xsl:value-of select="$trans/t[@o='notAvailable']"/>
   </xsl:when>
   <xsl:when test="$this/invalidFormat/@v != ''">
    <xsl:value-of select="concat('(', $trans/t[@o='invalidFormat'])"/>
    <xsl:text>: '</xsl:text>
    <xsl:value-of select="$this/invalidFormat/@v"/>
    <xsl:text>')</xsl:text>
   </xsl:when>
   <xsl:when test="$this/NSW/@v != ''">
     <xsl:value-of select="$trans/weather[@o='NSW']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:variable name="w_all">
     <xsl:apply-templates select="$this/descriptor"/>
     <xsl:apply-templates select="$this/phenomenon"/>
    </xsl:variable>
    <xsl:variable name="intensity">
     <xsl:choose>
      <xsl:when test="$this/intensity/@v = 'LIGHT'">
       <xsl:value-of select="$trans/weather[@o='phen-light']"/>
      </xsl:when>
      <xsl:when test="$this/intensity/@v = 'HEAVY'">
       <xsl:value-of select="$trans/weather[@o='phen-heavy']"/>
      </xsl:when>
      <xsl:otherwise>
       <xsl:choose>
        <xsl:when test="$is_recent = 1"></xsl:when>
        <xsl:when test="contains($w_all, 'DZ') or contains($w_all, 'RA') or contains($w_all, 'SN') or contains($w_all, 'SG') or contains($w_all, 'PL') or contains($w_all, 'GR') or contains($w_all, 'GS') or contains($w_all, 'DS') or contains($w_all, 'SS')">
         <xsl:value-of select="$trans/weather[@o='phen-moderate']"/>
        </xsl:when>
        <xsl:otherwise></xsl:otherwise>
       </xsl:choose>
      </xsl:otherwise>
     </xsl:choose>
    </xsl:variable>
    <xsl:variable name="w_all_trans">
     <xsl:choose>
      <xsl:when test="$trans/weather[@o=$w_all] != ''">
       <xsl:variable name="w_trans" select="$trans/weather[@o=$w_all]"/>
       <xsl:value-of select="concat(substring-before($w_trans, '|'), $intensity, substring-after($w_trans, '|'))"/>
      </xsl:when>
      <xsl:otherwise>
       <xsl:value-of select="$this/@s"/>
      </xsl:otherwise>
     </xsl:choose>
    </xsl:variable>
    <xsl:value-of select="$w_all_trans"/>
    <xsl:if test="$this/inVicinity/@v != ''">
      <xsl:value-of select="$trans/weather[@o='inVicinity']"/>
    </xsl:if>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="descriptor">
  <xsl:value-of select="@v"/>
 </xsl:template>

 <xsl:template match="phenomenon">
  <xsl:value-of select="@v"/>
 </xsl:template>

 <xsl:template match="cloudList">
  <xsl:param name="trans"/>
  <xsl:variable name="s_list">
   <xsl:apply-templates select="cloud" mode="list"/>
  </xsl:variable>
  <xsl:variable name="ceiling">
   <xsl:apply-templates select="cloud" mode="ceiling"/>
  </xsl:variable>
  <xsl:apply-templates select="cloud">
   <xsl:with-param name="ceiling" select="$ceiling"/>
   <xsl:with-param name="s_list" select="$s_list"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="cloud" mode="list">
  <xsl:value-of select="concat(' ', @s)"/>
 </xsl:template>

 <xsl:template match="cloud" mode="ceiling">
  <xsl:param name="trans"/>
  <xsl:if test="isCeiling/@v != '' and $strictfgfs != 1">
   <xsl:value-of select="cloudBase/@v"/>
  </xsl:if>
 </xsl:template>

 <xsl:template match="cloud">
  <xsl:param name="ceiling"/>
  <xsl:param name="s_list"/>
  <xsl:param name="trans"/>
  <xsl:choose>
   <xsl:when test="position() = 1">
    <xsl:variable name="rows">
     <xsl:choose>
      <xsl:when test="$ceiling != ''"><xsl:value-of select="last() + 1"/></xsl:when>
      <xsl:otherwise><xsl:value-of select="last()"/></xsl:otherwise>
     </xsl:choose>
    </xsl:variable>
    <tr>
    <xsl:if test="$method = 'html'">
     <xsl:element name="td">
      <xsl:attribute name="nowrap">1</xsl:attribute>
      <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
      <b><xsl:value-of select="$s_list"/></b>
     </xsl:element>
    </xsl:if>
    <xsl:choose>
     <xsl:when test="$ceiling != ''">
      <td nowrap="1"><xsl:value-of select="$trans/hdr[@o='ceiling']"/></td>
      <td nowrap="1">
      <xsl:value-of select="concat($trans/t[@o='cloud-at'], ' ', $ceiling * 100, ' ft')"/>
      </td>
      <xsl:text>&#9;&#9;&#9;&#9;</xsl:text>
      <td nowrap="1">
      <xsl:value-of select="concat(format-number($ceiling * 10 * $FT2M, '0') * 10, ' m')"/>
      </td>
     </xsl:when>
     <xsl:otherwise>
      <xsl:element name="td">
       <xsl:attribute name="nowrap">1</xsl:attribute>
       <xsl:attribute name="rowspan"><xsl:value-of select="last()"/></xsl:attribute>
       <xsl:value-of select="$trans/hdr[@o='cloud-1']"/>
      </xsl:element>
      <xsl:call-template name="printCloud">
       <xsl:with-param name="at_abv" select="'cloud-at'"/>
       <xsl:with-param name="trans" select="$trans"/>
      </xsl:call-template>
     </xsl:otherwise>
    </xsl:choose>
    </tr><xsl:text>&#10;</xsl:text>
    <xsl:if test="$ceiling != ''">
     <tr>
     <xsl:element name="td">
      <xsl:attribute name="nowrap">1</xsl:attribute>
      <xsl:attribute name="rowspan"><xsl:value-of select="last()"/></xsl:attribute>
      <xsl:value-of select="$trans/hdr[@o='cloud-1']"/>
     </xsl:element>
     <xsl:call-template name="printCloud">
      <xsl:with-param name="at_abv" select="'cloud-at'"/>
      <xsl:with-param name="trans" select="$trans"/>
     </xsl:call-template>
     </tr><xsl:text>&#10;</xsl:text>
    </xsl:if>
   </xsl:when>
   <xsl:otherwise>
    <tr>
    <xsl:text>&#9;&#9;&#9;</xsl:text>
    <xsl:call-template name="printCloud">
     <xsl:with-param name="at_abv" select="'cloud-at'"/>
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:call-template>
    </tr><xsl:text>&#10;</xsl:text>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template name="printCloud">
  <xsl:param name="trans"/>
  <xsl:param name="at_abv"/>
  <xsl:variable name="this" select="."/>
  <xsl:choose>
   <xsl:when test="notAvailable/@v != ''">
    <td nowrap="1" colspan="2">
     <xsl:value-of select="$trans/t[@o='notAvailable']"/>
    </td>
   </xsl:when>
   <xsl:when test="invalidFormat/@v != ''">
    <td nowrap="1" colspan="2">
    <xsl:value-of select="concat('(', $trans/t[@o='invalidFormat'])"/>
    <xsl:text>: '</xsl:text>
    <xsl:value-of select="invalidFormat/@v"/>
    <xsl:text>')</xsl:text>
    </td>
   </xsl:when>
   <xsl:when test="noClouds/@v != ''">
    <td nowrap="1" colspan="2">
    <xsl:choose>
     <xsl:when test="$strictfgfs != 1">
      <xsl:value-of select="$trans/cloudCover[@o=$this/noClouds/@v]"/>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="$trans/cloudCover[@o=concat($this/noClouds/@v,'-s')]"/>
     </xsl:otherwise>
    </xsl:choose>
    </td>
   </xsl:when>
   <xsl:otherwise>
    <xsl:element name="td">
     <xsl:attribute name="nowrap">1</xsl:attribute>
     <xsl:if test="not(cloudBase/@v != '')">
      <xsl:attribute name="colspan">2</xsl:attribute>
     </xsl:if>
     <xsl:value-of select="$trans/cloudCover[@o=$this/cloudCover/@v]"/>
     <xsl:if test="isThin/@v != ''">
      <xsl:value-of select="concat(' (', $trans/t[@o='thin'], ')')"/>
     </xsl:if>
     <xsl:choose>
      <xsl:when test="cloudBase/@v != ''">
       <xsl:value-of select="concat(' ', $trans/t[@o=$at_abv], ' ', cloudBase/@v * 100, ' ft')"/>
      </xsl:when>
      <xsl:otherwise>
       <xsl:value-of select="$trans/t[@o='cloudBaseNotAvailable']"/>
      </xsl:otherwise>
     </xsl:choose>
     <xsl:if test="cloudType/@v != ''">
      <br />
      <xsl:value-of select="concat(' (', $trans/cloudType[@o=$this/cloudType/@v], ')')"/>
     </xsl:if>
     <xsl:if test="cloudTypeNotAvailable/@v != ''">
      <xsl:value-of select="$trans/t[@o='cloudTypeNotAvailable']"/>
     </xsl:if>
    </xsl:element>
    <xsl:if test="cloudBase/@v != ''">
     <xsl:text>&#9;&#9;&#9;</xsl:text>
     <td nowrap="1">
     <xsl:value-of select="concat(format-number(cloudBase/@v * 10 * $FT2M, '0') * 10, ' m')"/>
     </td>
    </xsl:if>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="temperature">
  <xsl:param name="trans"/>
  <xsl:variable name="rows">
   <xsl:choose>
    <xsl:when test="air/temp/@v != '' and dewpoint/temp/@v != ''">3</xsl:when>
    <xsl:when test="air != '' and dewpoint != ''">2</xsl:when>
    <xsl:otherwise>1</xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <xsl:if test="air/temp/@v != ''">
   <tr>
   <xsl:call-template name="printTemp">
    <xsl:with-param name="hdr" select="$trans/hdr[@o='temperature-temp']"/>
    <xsl:with-param name="rows" select="$rows"/>
    <xsl:with-param name="s" select="@s"/>
    <xsl:with-param name="temp" select="air"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="dewpoint/temp/@v != '' or (dewpoint != '' and $method = 'html')">
   <tr>
   <xsl:call-template name="printTemp">
    <xsl:with-param name="hdr" select="$trans/hdr[@o='temperature-dew']"/>
    <xsl:with-param name="temp" select="dewpoint"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="relHumid1/@v != ''">
   <tr>
    <td nowrap="1"><xsl:value-of select="$trans/hdr[@o='relHumid']"/></td>
    <td nowrap="1" colspan="2">
     <xsl:value-of select="format-number(relHumid1/@v, '0')"/>
     <xsl:text>%</xsl:text>
    </td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="tempHourly">
  <xsl:param name="trans"/>
  <xsl:variable name="rows">
   <xsl:choose>
    <xsl:when test="air/temp/@v != '' and dewpoint/temp/@v != ''">2</xsl:when>
    <xsl:otherwise>1</xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <xsl:if test="air/temp/@v != ''">
   <tr>
   <xsl:call-template name="printTemp">
    <xsl:with-param name="hdr" select="$trans/hdr[@o='tempHourly-temp']"/>
    <xsl:with-param name="rows" select="$rows"/>
    <xsl:with-param name="s" select="@s"/>
    <xsl:with-param name="temp" select="air"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="dewpoint/temp/@v != ''">
   <tr>
   <xsl:call-template name="printTemp">
    <xsl:with-param name="hdr" select="$trans/hdr[@o='tempHourly-dew']"/>
    <xsl:with-param name="temp" select="dewpoint"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="tempMax|tempMin|tempAt|temp6hMax|temp6hMin|SST|OAT">
  <xsl:param name="trans"/>
  <tr>
  <xsl:variable name="this" select="."/>
  <xsl:call-template name="printTemp">
   <xsl:with-param name="hdr" select="$trans/hdr[@o=name($this)]"/>
   <xsl:with-param name="rows" select="1"/>
   <xsl:with-param name="s" select="@s"/>
   <xsl:with-param name="temp" select="."/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="temp24h">
  <xsl:param name="trans"/>
  <xsl:variable name="rows">
   <xsl:choose>
    <xsl:when test="temp24hMin/temp/@v != ''">2</xsl:when>
    <xsl:otherwise>1</xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <tr>
  <xsl:call-template name="printTemp">
   <xsl:with-param name="hdr" select="$trans/hdr[@o='temp24hMax']"/>
   <xsl:with-param name="rows" select="$rows"/>
   <xsl:with-param name="s" select="@s"/>
   <xsl:with-param name="temp" select="temp24hMax"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="temp24hMin/temp/@v != ''">
   <tr>
   <xsl:call-template name="printTemp">
    <xsl:with-param name="hdr" select="$trans/hdr[@o='temp24hMin']"/>
    <xsl:with-param name="temp" select="temp24hMin"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template name="printTemp">
  <xsl:param name="hdr"/>
  <xsl:param name="notavail"/>
  <xsl:param name="rows"/>
  <xsl:param name="s"/>
  <xsl:param name="temp"/>
  <xsl:param name="trans"/>
  <xsl:if test="$method = 'html' and $s != ''">
   <xsl:element name="td">
    <xsl:attribute name="nowrap">1</xsl:attribute>
    <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
    <b><xsl:value-of select="$s"/></b>
   </xsl:element>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$hdr"/>
  </td>
  <xsl:choose>
   <xsl:when test="$temp/notAvailable/@v != ''">
    <td nowrap="1" colspan="2">
    <xsl:value-of select="$trans/t[@o='notAvailable']"/>
    </td>
   </xsl:when>
   <xsl:otherwise>
    <td nowrap="1">
    <xsl:choose>
     <xsl:when test="$temp/tempUnit/@v = 'C'">
      <xsl:value-of select="$temp/temp/@v"/>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="format-number(($temp/temp/@v - 32) div 1.8, '0.#')"/>
     </xsl:otherwise>
    </xsl:choose>
    <xsl:text>C</xsl:text>
    <xsl:if test="$temp/hour/@v !=''">
     <xsl:value-of select="concat(substring-before($trans/t[@o='time-at'], '|'), $temp/hour/@v, ':00 UTC', substring-after($trans/t[@o='time-at'], '|'))"/>
    </xsl:if>
    </td>
    <xsl:choose>
     <xsl:when test="$temp/hour/@v !=''">
      <xsl:text>&#9;&#9;&#9;</xsl:text>
     </xsl:when>
     <xsl:otherwise>
      <xsl:text>&#9;&#9;&#9;&#9;&#9;</xsl:text>
     </xsl:otherwise>
    </xsl:choose>
    <td nowrap="1">
    <xsl:choose>
     <xsl:when test="$temp/tempUnit/@v = 'C'">
      <!--xsl:value-of select="format-number($temp/temp/@v * 1.8 + 32, '0.#')"/-->
      <xsl:value-of select="floor(10 * ($temp/temp/@v * 1.8 + 32 + 0.05)) div 10"/>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="$temp/temp/@v"/>
     </xsl:otherwise>
    </xsl:choose>
    <xsl:text>F</xsl:text>
    </td>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="QNH|somePressure|SLPdPa|SLPinHg|regQNH|QFE|QFF">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o=name($this)]"/>
  </td>
  <xsl:if test="inHg/@v != '' or hPa/@v != '' or mmHg/@v != ''">
   <td nowrap="1">
   <xsl:choose>
    <xsl:when test="hPa/@v != ''">
     <xsl:value-of select="hPa/@v"/>
    </xsl:when>
    <xsl:when test="mmHg/@v != ''">
     <xsl:value-of select="format-number(mmHg/@v div ($FT2M div 12 * 1000) * $INHG2HPA, '0')"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="format-number(inHg/@v * $INHG2HPA, '0')"/>
    </xsl:otherwise>
   </xsl:choose>
   <xsl:text> hPa</xsl:text>
   </td><xsl:text>&#9;&#9;&#9;&#9;</xsl:text><td nowrap="1">
   <xsl:choose>
    <xsl:when test="inHg/@v != ''">
     <xsl:value-of select="inHg/@v"/>
    </xsl:when>
    <xsl:when test="hPa/@v != ''">
     <xsl:value-of select="format-number(hPa/@v div $INHG2HPA, '0.##')"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="format-number(mmHg/@v div ($FT2M div 12 * 1000), '0.##')"/>
    </xsl:otherwise>
   </xsl:choose>
   <xsl:text> in. Hg</xsl:text>
   </td>
  </xsl:if>
  <xsl:if test="notAvailable/@v != ''">
   <td nowrap="1" colspan="2">
    <xsl:value-of select="$trans/t[@o='notAvailable']"/>
   </td>
  </xsl:if>
  <xsl:if test="invalidFormat/@v != ''">
   <td nowrap="1" colspan="2">
   <xsl:value-of select="concat('(', $trans/t[@o='invalidFormat'])"/>
   <xsl:text>: '</xsl:text>
   <xsl:value-of select="invalidFormat/@v"/>
   <xsl:text>')</xsl:text>
   </td>
  </xsl:if>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="cloudMaxCover">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1"><xsl:value-of select="$trans/hdr[@o='cloudMaxCover']"/></td>
   <td nowrap="1" colspan="2">
   <xsl:value-of select="$trans/cloudCover[@o=$this/cloudCover/@v]"/>
   </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="cloudAbove">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1"><xsl:value-of select="$trans/hdr[@o='cloud-1']"/></td>
  <xsl:call-template name="printCloud">
   <xsl:with-param name="at_abv" select="'cloud-above'"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="cloudCoverVar">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1" rowspan="2"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1"><xsl:value-of select="$trans/hdr[@o='cloudCoverVar']"/></td>
  <xsl:choose>
   <xsl:when test="cloudBase/@v != ''">
    <xsl:call-template name="printCloud">
     <xsl:with-param name="at_abv" select="'cloud-at'"/>
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:call-template>
   </xsl:when>
   <xsl:otherwise>
   <td nowrap="1" colspan="2">
   <xsl:value-of select="$trans/cloudCover[@o=$this/cloudCover/@v]"/>
   </td>
   </xsl:otherwise>
  </xsl:choose>
  </tr><xsl:text>&#10;</xsl:text>
  <tr>
  <td nowrap="1"><xsl:value-of select="$trans/hdr[@o='cloudCoverVar2']"/></td>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="$trans/cloudCover[@o=$this/cloudCover2/@v]"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="reportConcerns">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='reportConcerns']"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:variable name="chg">
   <xsl:value-of select="$trans/concernsChange[@o=$this/change/@v]"/>
  </xsl:variable>
  <xsl:value-of select="concat(substring-before($chg, '|'), $trans/concernsSubject[@o=$this/subject/@v], substring-after($chg, '|'))"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="cloudOpacityLvl">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='cloudOpacityLvl']"/>
  </td>
  <td nowrap="1">
  <xsl:value-of select="concat(eights/@v, '/8')"/>
  <xsl:if test="weather != ''">
   <xsl:text> </xsl:text>
   <xsl:call-template name="printWeather">
    <xsl:with-param name="is_recent" select="1"/>
    <xsl:with-param name="this" select="weather"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
  </xsl:if>
  <xsl:if test="cloudType/@v != ''">
   <xsl:value-of select="concat(' ', $trans/cloudType[@o=$this/cloudType/@v])"/>
  </xsl:if>
  <xsl:value-of select="concat(' ', $trans/t[@o='cloud-at'], ' ', cloudBase/@v * 100, ' ft')"/>
  <xsl:apply-templates select="locationAndList/locationThruList">
   <xsl:with-param name="compassDirDescr" select="$trans/t[@o='compassDirLocation']"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  </td>
  <xsl:text>&#9;&#9;</xsl:text>
  <td nowrap="1">
  <xsl:value-of select="concat(format-number(cloudBase/@v * 10 * $FT2M, '0') * 10, ' m')"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="RH">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1"><xsl:value-of select="$trans/hdr[@o='relHumid']"/></td>
  <td nowrap="1" colspan="2">
   <xsl:value-of select="RHVal/@v"/>
   <xsl:text>%</xsl:text>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="AI">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1"><xsl:value-of select="$trans/hdr[@o='AI']"/></td>
  <td nowrap="1" colspan="2">
   <xsl:value-of select="AIVal/@v"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="rwyState">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <xsl:choose>
   <xsl:when test="SNOCLO/@v != ''">
    <td nowrap="1" colspan="3">
    <xsl:value-of select="$trans/t[@o='SNOCLO']"/>
    </td>
   </xsl:when>
   <xsl:otherwise>
    <td nowrap="1">
    <xsl:value-of select="substring-before($trans/hdr[@o='stateOfRwy'], '|')"/>
    <xsl:choose>
     <xsl:when test="rwyDesigAll/@v != ''">
      <xsl:value-of select="$trans/t[@o='rwyDesigAll']"/>
     </xsl:when>
     <xsl:when test="rwyDesigRep/@v != ''">
      <xsl:value-of select="$trans/t[@o='rwyDesigRep']"/>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="concat(substring-before($trans/t[@o='rwyDesig'], '|'), rwyDesig/@v, substring-after($trans/t[@o='rwyDesig'], '|'))"/>
     </xsl:otherwise>
    </xsl:choose>
    <xsl:value-of select="substring-after($trans/hdr[@o='stateOfRwy'], '|')"/>
    </td>
    <td colspan="2">
    <xsl:choose>
     <xsl:when test="depositType/notAvailable/@v != '' and depositExtent/notAvailable/@v != '' and depositDepth/notAvailable/@v != '' and friction/notAvailable/@v != ''">
      <xsl:value-of select="$trans/t[@o='notAvailable']"/>
     </xsl:when>

     <xsl:otherwise>

      <xsl:if test="cleared/@v != ''">
       <xsl:value-of select="$trans/t[@o='cleared']"/>
      </xsl:if>

      <xsl:variable name="delim1">
       <xsl:if test="cleared/@v != ''">, </xsl:if>
      </xsl:variable>
      <xsl:if test="depositType/depositTypeVal/@v != ''">
       <xsl:value-of select="$delim1"/>
       <xsl:value-of select="$trans/depositType[@o=$this/depositType/depositTypeVal/@v]"/>
      </xsl:if>

      <xsl:variable name="delim2">
       <xsl:if test="$delim1 != '' or depositType/depositTypeVal/@v != ''">, </xsl:if>
      </xsl:variable>
      <xsl:if test="depositExtent/invalidFormat/@v != ''">
       <xsl:value-of select="$delim2"/>
       <xsl:value-of select="concat('(', $trans/t[@o='invalidFormat'])"/>
       <xsl:text>'</xsl:text>
       <xsl:value-of select="depositExtent/invalidFormat/@v"/>
       <xsl:text>')</xsl:text>
      </xsl:if>
      <xsl:if test="depositExtent/depositExtentVal/@v != ''">
       <xsl:value-of select="$delim2"/>
       <xsl:value-of select="substring-before($trans/depositExtent[@o=$this/depositExtent/depositExtentVal/@v], '|')"/>
       <xsl:if test="$strictfgfs != 1">
        <xsl:value-of select="$trans/t[@o='depositExtent']"/>
       </xsl:if>
       <xsl:value-of select="substring-after($trans/depositExtent[@o=$this/depositExtent/depositExtentVal/@v], '|')"/>
      </xsl:if>

      <xsl:variable name="delim3">
       <xsl:if test="$delim2 != '' or depositExtent/invalidFormat/@v != '' or depositExtent/depositExtentVal/@v != ''">, </xsl:if>
      </xsl:variable>
      <xsl:if test="depositDepth/invalidFormat/@v != ''">
       <xsl:value-of select="$delim3"/>
       <xsl:value-of select="concat('(', $trans/t[@o='invalidFormat'])"/>
       <xsl:text>: '</xsl:text>
       <xsl:value-of select="depositDepth/invalidFormat/@v"/>
       <xsl:text>')</xsl:text>
      </xsl:if>
      <xsl:if test="depositDepth/depositDepthVal/@v != ''">
       <xsl:value-of select="$delim3"/>
       <xsl:if test="$strictfgfs != 1">
        <xsl:value-of select="substring-before($trans/t[@o='depositDepth'], '|')"/>
       </xsl:if>
       <xsl:choose>
        <xsl:when test="depositDepth/depositDepthVal/@v &lt; 1">&lt;1 mm</xsl:when>
        <xsl:when test="depositDepth/depositDepthVal/@v &lt; 91">
         <xsl:value-of select="concat(depositDepth/depositDepthVal/@v, ' mm')"/>
        </xsl:when>
        <xsl:when test="depositDepth/depositDepthVal/@v &lt; 99">
         <xsl:value-of select="concat(50 * (depositDepth/depositDepthVal/@v - 90), ' mm')"/>
        </xsl:when>
        <xsl:otherwise>
         <xsl:value-of select="$trans/t[@o='rwyNotInUse']"/>
        </xsl:otherwise>
       </xsl:choose>
       <xsl:if test="$strictfgfs != 1">
        <xsl:value-of select="substring-after($trans/t[@o='depositDepth'], '|')"/>
       </xsl:if>
      </xsl:if>
      <xsl:variable name="delim4">
       <xsl:if test="$delim3 != '' or depositDepth/invalidFormat/@v != '' or depositDepth/depositDepthVal/@v != ''">, </xsl:if>
      </xsl:variable>
      <xsl:if test="friction/invalidFormat/@v != ''">
       <xsl:value-of select="$delim4"/>
       <xsl:value-of select="concat('(', $trans/t[@o='invalidFormat'])"/>
       <xsl:text>: '</xsl:text>
       <xsl:value-of select="friction/invalidFormat/@v"/>
       <xsl:text>')</xsl:text>
      </xsl:if>
      <xsl:if test="friction/coefficient/@v != ''">
       <xsl:value-of select="$delim4"/>
       <xsl:value-of select="concat($trans/t[@o='friction'], format-number(friction/coefficient/@v div 100, '0.00'))"/>
      </xsl:if>
      <xsl:if test="friction/brakingAction/@v != ''">
       <xsl:value-of select="$delim4"/>
       <xsl:value-of select="$trans/friction[@o=$this/friction/brakingAction/@v]"/>
      </xsl:if>
      <xsl:if test="friction/unreliable/@v != ''">
       <xsl:value-of select="$delim4"/>
       <xsl:value-of select="$trans/friction[@o='99']"/>
      </xsl:if>
     </xsl:otherwise>
    </xsl:choose>
    </td>
    </xsl:otherwise>
   </xsl:choose>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="windShear">
  <xsl:param name="trans"/>
  <tr>
   <xsl:if test="$method = 'html'">
    <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
   </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="substring-before($trans/hdr[@o='windShearRwy'], '|')"/>
  <xsl:choose>
   <xsl:when test="rwyDesigAll/@v != ''">
    <xsl:value-of select="$trans/t[@o='rwyDesigAll']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="concat(substring-before($trans/t[@o='rwyDesig'], '|'), rwyDesig/@v, substring-after($trans/t[@o='rwyDesig'], '|'))"/>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:value-of select="substring-after($trans/hdr[@o='windShearRwy'], '|')"/>
  </td>
  <td nowrap="1" colspan="2">
    <xsl:value-of select="$trans/t[@o='windShear']"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="recentWeatherList">
  <xsl:param name="trans"/>
  <xsl:variable name="s_list">
   <xsl:apply-templates select="weather" mode="list"/>
  </xsl:variable>
  <xsl:apply-templates select="weather">
   <xsl:with-param name="s_list" select="$s_list"/>
   <xsl:with-param name="hdr1" select="$trans/hdr[@o='recentWeather-1']"/>
   <xsl:with-param name="is_recent" select="1"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="colourCode">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:variable name="rows">
   <xsl:choose>
    <xsl:when test="BLACK/@v != '' and currentColour/@v != '' and predictedColour/@v != ''">3</xsl:when>
    <xsl:when test="BLACK/@v != '' and currentColour/@v != ''">2</xsl:when>
    <xsl:when test="currentColour/@v != '' and predictedColour/@v != ''">2</xsl:when>
    <xsl:otherwise>1</xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <tr>
  <xsl:if test="$method = 'html'">
   <xsl:element name="td">
    <xsl:attribute name="nowrap">1</xsl:attribute>
    <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
    <b><xsl:value-of select="@s"/></b>
   </xsl:element>
  </xsl:if>
  <xsl:element name="td">
   <xsl:attribute name="nowrap">1</xsl:attribute>
   <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
   <xsl:value-of select="$trans/hdr[@o='colourCode']"/>
  </xsl:element>
  <td nowrap="1" colspan="2">
  <xsl:choose>
   <xsl:when test="BLACK/@v != ''">
    <xsl:value-of select="$trans/colour[@o='BLACK']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/colour[@o=$this/currentColour/@v]"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="BLACK/@v != ''">
   <xsl:text>&#9;&#9;&#9;</xsl:text>
   <tr>
   <td nowrap="1" colspan="2">
   <xsl:value-of select="$trans/colour[@o=$this/currentColour/@v]"/>
   </td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="predictedColour/@v != ''">
   <xsl:text>&#9;&#9;&#9;</xsl:text>
   <tr>
   <td nowrap="1" colspan="2">
   <xsl:value-of select="$trans/t[@o='predictedColour']"/>
   <br /><xsl:text>&#10;&#9;&#9;&#9;</xsl:text>
   <xsl:choose>
    <xsl:when test="currentColour/@v != predictedColour/@v">
     <xsl:value-of select="$trans/colour[@o=$this/predictedColour/@v]"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="$trans/colour[@o='noChange']"/>
    </xsl:otherwise>
   </xsl:choose>
   </td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="windShearLvl">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1" rowspan="2"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1" rowspan="2">
  <xsl:value-of select="$trans/hdr[@o='windShearLvl']"/>
  </td>
  <td nowrap="1">
  <xsl:value-of select="concat($trans/t[@o='topOfLayer'], ' ', level/@v * 100, ' ft')"/>
  </td>
  <xsl:text>&#9;&#9;&#9;</xsl:text>
  <td nowrap="1">
  <xsl:value-of select="concat(format-number(level/@v * 10 * $FT2M, '0') * 10, ' m')"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <tr>
  <xsl:text>&#9;&#9;&#9;</xsl:text>
  <xsl:variable name="dir">
   <xsl:value-of select="concat($trans/t[@o='wind-from'], ' ')"/>
   <xsl:value-of select="$trans/compassDir16/arr[position()=1+format-number($this/wind/dir/@v div 45 * 2, '0')]"/>
   <xsl:value-of select="concat(' (', wind/dir/@v, ')')"/>
  </xsl:variable>
  <xsl:variable name="speed">
   <xsl:call-template name="speed2kt">
    <xsl:with-param name="speed" select="wind/speed/@v"/>
    <xsl:with-param name="unit" select="wind/unitSpeed/@v"/>
   </xsl:call-template>
  </xsl:variable>
  <xsl:call-template name="printSpeed">
   <xsl:with-param name="dir" select="$dir"/>
   <xsl:with-param name="speed" select="$speed"/>
   <xsl:with-param name="delim" select="'&#9;&#9;'"/>
   <xsl:with-param name="greater" select="speedGreater/@v"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template name="printLayerHeight">
  <xsl:param name="height"/>
  <xsl:value-of select="concat($height, ' m (', format-number($height div $FT2M div 100, '#0'), '00 ft) AGL')"/>
 </xsl:template>

 <xsl:template match="turbulence|icing">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o=name($this)]"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="$trans/turbulenceDescr[@o=$this/turbulenceDescr/@v]"/>
  <xsl:value-of select="$trans/icingDescr[@o=$this/icingDescr/@v]"/>
  <xsl:value-of select="concat(', ', $trans/t[@o='level-from'], ' ')"/>
  <xsl:choose>
   <!-- WMO 306 Vol I.1 Part A, coding table 1690 -->
   <xsl:when test="layerBase/@v = '0'">
    <xsl:text>&lt;30 m (&lt;100 ft) AGL</xsl:text>
   </xsl:when>
   <xsl:otherwise>
    <xsl:call-template name="printLayerHeight">
     <xsl:with-param name="height" select="layerBase/@v * 30"/>
    </xsl:call-template>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:choose>
   <xsl:when test="layerTop/@v != ''">
    <xsl:value-of select="concat(' ', $trans/t[@o='level-to'], ' ')"/>
    <xsl:call-template name="printLayerHeight">
     <xsl:with-param name="height" select="layerTop/@v * 30"/>
    </xsl:call-template>
   </xsl:when>
   <xsl:when test="layerThickness/@v = '0'">
    <xsl:value-of select="$trans/t[@o='toTopOfCloud']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="concat(' ', $trans/t[@o='level-to'], ' ')"/>
    <!-- layerThickness: WMO 306 Vol I.1 Part A, coding table 0300 -->
    <xsl:call-template name="printLayerHeight">
     <xsl:with-param name="height" select="layerBase/@v * 30 + layerThickness/@v * 300"/>
    </xsl:call-template>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="amendment">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1" colspan="3">
  <xsl:value-of select="concat($trans/t[@o='amendment'], ' ')"/>
  <xsl:choose>
   <xsl:when test="isNotScheduled/@v != ''">
    <xsl:value-of select="$trans/t[@o='isNotScheduled']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/t[@o='isLtdToCldVisWind']"/>
    <xsl:if test="hourFrom/@v != ''">
     <xsl:value-of select="concat(' ', substring-before($trans/t[@o='time-from'], '|'), hourFrom/@v, ':00 UTC', substring-after($trans/t[@o='time-from'], '|'))"/>
    </xsl:if>
    <xsl:if test="hourTill/@v != ''">
     <xsl:value-of select="concat(' ', substring-before($trans/t[@o='time-till'], '|'), hourTill/@v, ':00 UTC', substring-after($trans/t[@o='time-till'], '|'))"/>
    </xsl:if>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="trendList">
  <xsl:param name="trans"/>
  <xsl:text>&#10;</xsl:text>
  <tr>
  <td></td>
  <td nowrap="1" colspan="3"><b>
   <xsl:if test="name(..) = 'metar'">
    <xsl:value-of select="$trans/hdr[@o='trendList']"/>
   </xsl:if>
   <xsl:if test="name(..) != 'metar'">
    <xsl:value-of select="$trans/hdr[@o='trendListTAF']"/>
   </xsl:if>
   <xsl:if test="$method != 'html'">
    <xsl:if test="name(..) = 'metar'">
     <xsl:value-of select="concat('&#10;', $trans/hdr[@o='trendList_ul'])"/>
    </xsl:if>
    <xsl:if test="name(..) != 'metar'">
     <xsl:value-of select="concat('&#10;', $trans/hdr[@o='trendListTAF_ul'])"/>
    </xsl:if>
   </xsl:if>
  </b></td>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:apply-templates select="trend">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="trend">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1" colspan="3">
  <xsl:choose>
   <xsl:when test="trendType/@v = 'NOSIG'">
    <xsl:value-of select="$trans/t[@o='NOSIG']"/>
   </xsl:when>
   <xsl:otherwise>
    <b>
    <xsl:if test="probability/@v != ''">
     <xsl:value-of select="concat(substring-before($trans/t[@o='prob'], '|'), probability/@v, substring-after($trans/t[@o='prob'], '|'))"/>
    </xsl:if>
    <xsl:if test="trendTime1 != ''">
     <xsl:if test="probability/@v != ''"><xsl:text> </xsl:text></xsl:if>
     <xsl:variable name="timeSpec">
      <xsl:choose>
       <xsl:when test="trendTime1/timeSpec/@v = 'AT'">
        <xsl:value-of select="$trans/t[@o='time-at']"/>
       </xsl:when>
       <xsl:when test="trendTime1/timeSpec/@v = 'FM'">
        <xsl:value-of select="$trans/t[@o='time-from']"/>
       </xsl:when>
       <xsl:otherwise>
        <xsl:value-of select="$trans/t[@o='time-till']"/>
       </xsl:otherwise>
      </xsl:choose>
     </xsl:variable>
     <xsl:value-of select="concat(substring-before($timeSpec, '|'), trendTime1/hour/@v, ':', trendTime1/minute/@v, ' UTC', substring-after($timeSpec, '|'))"/>
     <xsl:if test="trendTime2 != ''">
      <xsl:value-of select="concat(' ', substring-before($trans/t[@o='time-till'], '|'), trendTime2/hour/@v, ':', trendTime2/minute/@v, ' UTC', substring-after($trans/t[@o='time-till'], '|'))"/>
     </xsl:if>
    </xsl:if>
    <xsl:if test="$trans/t[@o=$this/trendType/@v] != ':' and (probability/@v != '' or trendTime1 != '')">
     <xsl:text> </xsl:text>
    </xsl:if>
    <xsl:value-of select="$trans/t[@o=$this/trendType/@v]"/>
    </b>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:apply-templates select="sfcWind">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="CAVOK">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="visPrev">
   <xsl:with-param name="unitThreshold" select="1000"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="visVert">
   <xsl:with-param name="unitThreshold" select="1000"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="weatherList">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="cloudList">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="colourCode">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="windShearLvl|turbulence|icing">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="remarkList">
  <xsl:param name="trans"/>
  <xsl:text>&#10;</xsl:text>
  <tr>
  <xsl:if test="$method = 'html'">
   <td><b>RMK</b></td>
  </xsl:if>
  <td nowrap="1" colspan="3"><b>
   <xsl:value-of select="$trans/hdr[@o='remarkList']"/>
   <xsl:if test="$method != 'html'">
    <xsl:value-of select="concat('&#10;', $trans/hdr[@o='remarkList_ul'])"/>
   </xsl:if>
  </b></td>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:apply-templates select="remark">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="remark">
  <xsl:param name="trans"/>
  <xsl:variable name="rmk">
   <xsl:value-of select="name(child::*[last()])"/>
  </xsl:variable>
  <xsl:choose>
   <xsl:when test="$rmk = 'wetRunway'">
    <xsl:apply-templates select="freetext">
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:apply-templates>
   </xsl:when>
   <xsl:when test="$rmk = 'cloud'">
    <xsl:apply-templates select="cloud">
     <xsl:with-param name="trans" select="$trans"/>
     <xsl:with-param name="s_list" select="cloud/@s"/>
    </xsl:apply-templates>
   </xsl:when>
   <xsl:when test="$rmk = 'visRwy'">
    <xsl:apply-templates select="visRwy">
     <xsl:with-param name="trans" select="$trans"/>
     <xsl:with-param name="unitThreshold" select="1000"/>
    </xsl:apply-templates>
   </xsl:when>
   <xsl:otherwise>
    <xsl:apply-templates select="child::*[last()]">
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:apply-templates>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="freetext">
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1" colspan="3">
  <pre style="margin: 0;">
  <xsl:value-of select="."/>
  </pre>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="WARNING">
  <tr>
  <td nowrap="1" colspan="4">
  <pre style="margin: 0;">
  <xsl:value-of select="."/>
  </pre>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="needMaint">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td colspan="3">
  <xsl:value-of select="$trans/t[@o=name($this)]"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="CAVOK|PWINO|FZRANO|TSNO|PNO|RVRNO|PRESFR|PRESRR|AURBO|NOSPECI|RCRNR">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="name(.)"/></b></td>
  </xsl:if>
  <td colspan="3">
   <xsl:value-of select="$trans/t[@o=name($this)]"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="obsStationType">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1" colspan="3">
  <xsl:value-of select="$trans/stationType[@o=$this/stationType/@v]"/>
  </td></tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="visListLoc">
  <xsl:param name="trans"/>
  <xsl:apply-templates select="visLocData">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="visLocData">
  <xsl:param name="trans"/>
  <tr>
  <xsl:if test="position() = 1">
   <xsl:if test="$method = 'html'">
    <xsl:element name="td">
     <xsl:attribute name="rowspan"><xsl:value-of select="last()"/></xsl:attribute>
     <b><xsl:value-of select="../@s"/></b>
    </xsl:element>
   </xsl:if>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="substring-before($trans/hdr[@o='visLoc'], '|')"/>
  <xsl:apply-templates select="locationAndList/locationThruList">
   <xsl:with-param name="compassDirDescr" select="$trans/t[@o='compassDirLocation']"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:value-of select="substring-after($trans/hdr[@o='visLoc'], '|')"/>
  </td>
  <xsl:call-template name="visibility">
   <xsl:with-param name="notavail" select="$trans/t[@o='notAvailable']"/>
   <xsl:with-param name="rnd_m" select="10"/>
   <xsl:with-param name="unitThreshold" select="1000"/>
   <xsl:with-param name="visVal" select="visibility"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="locationThruList">
  <xsl:param name="compassDirDescr"/>
  <xsl:param name="trans"/>
  <xsl:if test="position() != 1">
   <xsl:value-of select="concat(' ', $trans/t[@o='loc-and'])"/>
  </xsl:if>
  <xsl:apply-templates select="location">
   <xsl:with-param name="compassDirDescr" select="$compassDirDescr"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="location">
  <xsl:param name="compassDirDescr"/>
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:if test="isDistant/@v != ''">
   <xsl:value-of select="$trans/t[@o='distant']"/>
  </xsl:if>
  <xsl:if test="inVicinity/@v != ''">
   <xsl:value-of select="$trans/weather[@o='inVicinity']"/>
  </xsl:if>
  <xsl:if test="locationSpec/@v != ''">
   <xsl:value-of select="concat(' ', $trans/locationSpec[@o=$this/locationSpec/@v])"/>
  </xsl:if>
  <xsl:if test="obscgMtns/@v != ''">
   <xsl:value-of select="$trans/t[@o='obscgMtns']"/>
  </xsl:if>
  <xsl:if test="isGrid/@v != ''">
   <xsl:value-of select="$trans/t[@o='isGrid']"/>
  </xsl:if>
  <xsl:if test="distance/@v != ''">
   <xsl:value-of select="concat(' ', distance/@v, ' ', unitLength/@v)"/>
  </xsl:if>
  <xsl:if test="quadrantList != ''">
   <xsl:text> </xsl:text>
   <xsl:for-each select="quadrantList/quadrant">
    <xsl:variable name="this2" select="."/>
    <xsl:if test="position() != 1">
     <xsl:value-of select="concat(' ', $trans/t[@o='loc-to'], ' ')"/>
    </xsl:if>
    <xsl:value-of select="$trans/quadrant[@o=$this2/@v]"/>
   </xsl:for-each>
   <xsl:value-of select="concat(' ', $trans/t[@o='quadrant'])"/>
  </xsl:if>
  <xsl:if test="compassDir/@v != ''">
   <xsl:if test="position() = 1">
    <xsl:value-of select="substring-before($compassDirDescr, '|')"/>
   </xsl:if>
   <xsl:if test="position() != 1">
    <xsl:value-of select="substring-before($trans/t[@o='compassDirDirection2'], '|')"/>
   </xsl:if>
   <xsl:value-of select="$trans/compassDir[@o=$this/compassDir/@v]"/>
   <xsl:if test="position() = 1">
    <xsl:value-of select="substring-after($compassDirDescr, '|')"/>
   </xsl:if>
   <xsl:if test="position() != 1">
    <xsl:value-of select="substring-after($trans/t[@o='compassDirDirection2'], '|')"/>
   </xsl:if>
  </xsl:if>
  <xsl:if test="isQuadrant/@v != ''">
   <xsl:value-of select="concat(' ', $trans/t[@o='quadrant'])"/>
  </xsl:if>
 </xsl:template>

 <xsl:template match="visAt">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
   <xsl:value-of select="$trans/visAt[@o=$this/locationAt/@v]"/>
  </td>
  <xsl:call-template name="visibility">
   <xsl:with-param name="notavail" select="$trans/t[@o='notAvailable']"/>
   <xsl:with-param name="rnd_m" select="10"/>
   <xsl:with-param name="unitThreshold" select="1000"/>
   <xsl:with-param name="visVal" select="visibility"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="visMin">
  <xsl:param name="trans"/>
  <tr>
  <xsl:call-template name="visibility_str">
   <xsl:with-param name="str" select="@s"/>
   <xsl:with-param name="rows" select="1"/>
  </xsl:call-template>
  <xsl:call-template name="visibility_header">
   <xsl:with-param name="header" select="$trans/hdr[@o='rmkVisMin']"/>
   <xsl:with-param name="rows" select="1"/>
  </xsl:call-template>
  <xsl:call-template name="visibility">
   <xsl:with-param name="notavail" select="$trans/t[@o='notAvailable']"/>
   <xsl:with-param name="rnd_m" select="10"/>
   <xsl:with-param name="unitThreshold" select="1000"/>
   <xsl:with-param name="visVal" select="."/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="visVar2">
  <xsl:param name="trans"/>
  <tr>
  <xsl:call-template name="visibility_str">
   <xsl:with-param name="str" select="../visVar1/@s"/>
   <xsl:with-param name="rows" select="2"/>
  </xsl:call-template>
  <xsl:call-template name="visibility_header">
   <xsl:with-param name="header" select="$trans/hdr[@o='rmkVisVar']"/>
   <xsl:with-param name="rows" select="1"/>
  </xsl:call-template>
  <xsl:call-template name="visibility">
   <xsl:with-param name="notavail" select="$trans/t[@o='notAvailable']"/>
   <xsl:with-param name="rnd_m" select="10"/>
   <xsl:with-param name="unitThreshold" select="1000"/>
   <xsl:with-param name="visVal" select="../visVar1"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
  <tr>
  <xsl:call-template name="visibility_header">
   <xsl:with-param name="header" select="$trans/t[@o='varying-to']"/>
   <xsl:with-param name="rows" select="1"/>
  </xsl:call-template>
  <xsl:call-template name="visibility">
   <xsl:with-param name="notavail" select="$trans/t[@o='notAvailable']"/>
   <xsl:with-param name="rnd_m" select="10"/>
   <xsl:with-param name="unitThreshold" select="1000"/>
   <xsl:with-param name="visVal" select="."/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="correctedAt">
  <xsl:param name="trans"/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='correctedAt']"/>
  </td>
  <td nowrap="1" colspan="3">
  <xsl:value-of select="concat(format-number(hour/@v, '00'), ':', format-number(minute/@v, '00'), ' UTC')"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="precipHourly">
  <xsl:param name="trans"/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:choose>
   <xsl:when test="precipHours/@v = '1'">
    <xsl:value-of select="$trans/hdr[@o='precip1Hour']"/>
   </xsl:when>
   <xsl:when test="precipHours/@v = '3'">
    <xsl:value-of select="$trans/hdr[@o='precip3Hour']"/>
   </xsl:when>
   <xsl:when test="precipHours/@v = '6'">
    <xsl:value-of select="$trans/hdr[@o='precip6Hour']"/>
   </xsl:when>
   <xsl:when test="precipHours/@v = '24'">
    <xsl:value-of select="$trans/hdr[@o='precip24Hour']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/hdr[@o='precip36Hour']"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  <xsl:choose>
   <xsl:when test="notAvailable/@v != ''">
    <td nowrap="1" colspan="2">
    <xsl:value-of select="$trans/t[@o='notAvailable']"/>
    </td>
   </xsl:when>
   <xsl:otherwise>
    <td nowrap="1">
    <xsl:value-of select="concat(format-number(precipVal/@v * ($FT2M div 12 * 1000), '0'), ' mm')"/>
    </td>
    <xsl:text>&#9;&#9;&#9;&#9;&#9;</xsl:text>
    <td nowrap="1">
    <xsl:value-of select="concat(precipVal/@v, ' in.')"/>
    </td>
   </xsl:otherwise>
  </xsl:choose>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="snowIncr">
  <xsl:param name="trans"/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='snowIncr']"/>
  </td>
  <td nowrap="1" colspan="3">
  <xsl:value-of select="substring-before($trans/t[@o='snowIncrPastHour'],'|')"/>
  <xsl:value-of select="pastHour/@v"/>
  <xsl:value-of select="substring-after($trans/t[@o='snowIncrPastHour'], '|')"/>
  <xsl:text>, </xsl:text>
  <xsl:value-of select="substring-before($trans/t[@o='snowIncrOnGround'],'|')"/>
  <xsl:value-of select="onGround/@v"/>
  <xsl:value-of select="substring-after($trans/t[@o='snowIncrOnGround'], '|')"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="cloudTypeFamily">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1" rowspan="3"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td rowspan="3">
  <xsl:value-of select="$trans/hdr[@o='cloudTypeFamily']"/>
  </td>
  <td colspan="2">
  <xsl:text>&#9;</xsl:text><xsl:value-of select="$trans/t[@o='low']"/>
  <xsl:choose>
   <xsl:when test="cloudTypeLow/@v != ''">
    <xsl:value-of select="$trans/cloudTypeLow[@o=$this/cloudTypeLow/@v]"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/t[@o='cloudLayerAboveOvercast']"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <tr>
  <td colspan="2">
  <xsl:text>&#9;</xsl:text><xsl:value-of select="$trans/t[@o='middle']"/>
  <xsl:choose>
   <xsl:when test="cloudTypeMiddle/@v != ''">
    <xsl:value-of select="$trans/cloudTypeMiddle[@o=$this/cloudTypeMiddle/@v]"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/t[@o='cloudLayerAboveOvercast']"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <tr>
  <td colspan="2">
  <xsl:text>&#9;</xsl:text><xsl:value-of select="$trans/t[@o='high']"/>
  <xsl:choose>
   <xsl:when test="cloudTypeHigh/@v != ''">
    <xsl:value-of select="$trans/cloudTypeHigh[@o=$this/cloudTypeHigh/@v]"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/t[@o='cloudLayerAboveOvercast']"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="windShift">
  <xsl:param name="trans"/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1" colspan="3">
  <xsl:value-of select="$trans/hdr[@o='windShift']"/>
  <xsl:call-template name="printTime">
   <xsl:with-param name="time"  select="."/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  <xsl:if test="FROPA/@v != ''">
   <xsl:value-of select="concat(' ', $trans/t[@o='FROPA'])"/>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="beginEndPrecip">
  <xsl:param name="trans"/>
  <xsl:variable name="rows">
   <xsl:apply-templates select="precip" mode="count"/>
  </xsl:variable>
  <tr>
  <xsl:if test="$method = 'html'">
   <xsl:element name="td">
    <xsl:attribute name="nowrap">1</xsl:attribute>
    <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
    <b><xsl:value-of select="@s"/></b>
   </xsl:element>
  </xsl:if>
  <xsl:element name="td">
   <xsl:attribute name="nowrap">1</xsl:attribute>
   <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
   <xsl:value-of select="$trans/hdr[@o='beginEndPrecip']"/>
  </xsl:element>
  <xsl:apply-templates select="precip">
   <xsl:with-param name="is_first" select="1"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  </tr>
  <xsl:apply-templates select="precip">
   <xsl:with-param name="is_first" select="0"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:if test="MOV != '' or MOVD != '' or locationAndList != ''">
   <tr>
   <td nowrap="1" colspan="2">
   <xsl:text>&#9;&#9;&#9;</xsl:text>
   <xsl:if test="locationAndList != ''">
    <xsl:apply-templates select="locationAndList/locationThruList">
     <xsl:with-param name="compassDirDescr" select="$trans/t[@o='compassDirLocation']"/>
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:apply-templates>
    <xsl:if test="MOV != '' or MOVD != ''">
     <xsl:text>,</xsl:text>
    </xsl:if>
   </xsl:if>
   <xsl:if test="MOV != ''">
    <xsl:value-of select="$trans/t[@o='MOV']"/>
    <xsl:apply-templates select="MOV/locationAndList/locationThruList">
     <xsl:with-param name="compassDirDescr" select="$trans/t[@o='compassDirDirection']"/>
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:apply-templates>
   </xsl:if>
   <xsl:if test="MOVD != ''">
    <xsl:value-of select="$trans/t[@o='MOVD']"/>
    <xsl:apply-templates select="MOVD/locationAndList/locationThruList">
     <xsl:with-param name="compassDirDescr" select="$trans/t[@o='compassDirDirection']"/>
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:apply-templates>
   </xsl:if>
   </td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="precip" mode="count">
  <xsl:if test="position() = last()">
   <xsl:choose>
    <xsl:when test="../MOV != '' or ../MOVD != '' or ../locationAndList != ''">
     <xsl:value-of select="last() + 1"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="last()"/>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:if>
 </xsl:template>

 <xsl:template match="precip">
  <xsl:param name="is_first"/>
  <xsl:param name="trans"/>
  <xsl:if test="$is_first = '1' and position() = 1">
   <td nowrap="1" colspan="2">
   <dl style="margin: 0em;"><dt>
   <xsl:call-template name="printWeather">
    <xsl:with-param name="is_recent" select="1"/>
    <xsl:with-param name="this" select="."/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   <xsl:text>:&#10;</xsl:text></dt>
   <xsl:apply-templates select="beginPrecip|endPrecip">
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:apply-templates>
   </dl></td>
  </xsl:if>
  <xsl:if test="$is_first = '0' and position() != 1">
   <xsl:text>&#9;&#9;&#9;</xsl:text>
   <tr>
   <td nowrap="1" colspan="2">
   <dl style="margin: 0em;"><dt>
   <xsl:call-template name="printWeather">
    <xsl:with-param name="is_recent" select="1"/>
    <xsl:with-param name="this" select="."/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   <xsl:text>:&#10;</xsl:text></dt>
   <xsl:apply-templates select="beginPrecip|endPrecip">
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:apply-templates>
   </dl></td>
   </tr>
  </xsl:if>
 </xsl:template>

 <xsl:template match="beginPrecip|endPrecip">
  <xsl:param name="trans"/>
  <xsl:text>&#9;&#9;&#9;&#9;</xsl:text><dd>
  <xsl:if test="name(.) = 'beginPrecip'">
   <xsl:value-of select="$trans/t[@o='began']"/>
  </xsl:if>
  <xsl:if test="name(.) = 'endPrecip'">
   <xsl:value-of select="$trans/t[@o='ended']"/>
  </xsl:if>
  <xsl:call-template name="printTime">
   <xsl:with-param name="time"  select="."/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  <xsl:text>&#10;</xsl:text></dd>
 </xsl:template>

 <xsl:template match="visLower|cigLower">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1" colspan="3">
  <xsl:value-of select="$trans/hdr[@o=name($this)]"/>
  <xsl:apply-templates select="locationAndList/locationThruList">
   <xsl:with-param name="compassDirDescr" select="$trans/t[@o='compassDirLocation']"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="cloudTypeList">
  <xsl:param name="trans"/>
  <xsl:for-each select="cloudType">
   <xsl:variable name="this" select="."/>
   <xsl:if test="position() != 1">
    <xsl:value-of select="concat(' ', $trans/t[@o='loc-and'], ' ')"/>
   </xsl:if>
   <xsl:value-of select="$trans/cloudType[@o=$this/@v]"/>
  </xsl:for-each>
 </xsl:template>

 <xsl:template match="lightningTypeList">
  <xsl:param name="trans"/>
  <xsl:for-each select="lightningType">
   <xsl:variable name="this" select="."/>
   <xsl:if test="position() != 1">
    <xsl:value-of select="concat(' ', $trans/t[@o='loc-and'], ' ')"/>
   </xsl:if>
   <xsl:value-of select="$trans/lightningType[@o=$this/@v]"/>
  </xsl:for-each>
 </xsl:template>

 <xsl:template match="phenomLocation">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1" colspan="3">
  <xsl:if test="isLow/@v != ''">
   <xsl:value-of select="concat($trans/t[@o='isLow'], ' ')"/>
  </xsl:if>
  <xsl:if test="isOccasional/@v != ''">
   <xsl:value-of select="concat($trans/t[@o='isOccasional'], ' ')"/>
  </xsl:if>
  <xsl:if test="isLight/@v != ''">
   <xsl:value-of select="concat($trans/t[@o='isLight'], ' ')"/>
  </xsl:if>
  <xsl:if test="isVeryLight/@v != ''">
   <xsl:value-of select="concat($trans/t[@o='isVeryLight'], ' ')"/>
  </xsl:if>
  <xsl:if test="isIntermittent/@v != ''">
   <xsl:value-of select="concat($trans/t[@o='isIntermittent'], ' ')"/>
  </xsl:if>
  <xsl:if test="isContinuous/@v != ''">
   <xsl:value-of select="concat($trans/t[@o='isContinuous'], ' ')"/>
  </xsl:if>
  <xsl:if test="isIsolated/@v != ''">
   <xsl:value-of select="concat($trans/t[@o='isIsolated'], ' ')"/>
  </xsl:if>
  <xsl:choose>
   <xsl:when test="weather != ''">
    <xsl:call-template name="printWeather">
     <xsl:with-param name="is_recent" select="1"/>
     <xsl:with-param name="this" select="weather"/>
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:call-template>
   </xsl:when>
   <xsl:when test="cloudTypeList != ''">
    <xsl:apply-templates select="cloudTypeList">
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:apply-templates>
   </xsl:when>
   <xsl:when test="cloudCover/@v != ''">
    <xsl:value-of select="$trans/cloudCover[@o=$this/cloudCover/@v]"/>
   </xsl:when>
   <xsl:when test="lightningTypeList != ''">
    <xsl:value-of select="concat($trans/phenomenon[@o='LTG'], ' ')"/>
    <xsl:apply-templates select="lightningTypeList">
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:apply-templates>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/phenomenon[@o=$this/otherPhenom/@v]"/>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:if test="fromContrails/@v != ''">
   <xsl:value-of select="concat(' ', $trans/t[@o='fromContrails'])"/>
  </xsl:if>
  <xsl:if test="inPastHour/@v != ''">
   <xsl:value-of select="concat(' ', $trans/t[@o='inPastHour'])"/>
  </xsl:if>
  <xsl:if test="locationAndList != ''">
   <xsl:apply-templates select="locationAndList/locationThruList">
    <xsl:with-param name="compassDirDescr" select="$trans/t[@o='compassDirLocation']"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:apply-templates>
   <xsl:if test="MOV != '' or MOVD != ''">
    <xsl:text>,</xsl:text>
   </xsl:if>
  </xsl:if>
  <xsl:if test="MOV != ''">
   <xsl:value-of select="$trans/t[@o='MOV']"/>
   <xsl:apply-templates select="MOV/locationAndList/locationThruList">
    <xsl:with-param name="compassDirDescr" select="$trans/t[@o='compassDirDirection']"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:apply-templates>
  </xsl:if>
  <xsl:if test="MOVD != ''">
   <xsl:value-of select="$trans/t[@o='MOVD']"/>
   <xsl:apply-templates select="MOVD/locationAndList/locationThruList">
    <xsl:with-param name="compassDirDescr" select="$trans/t[@o='compassDirDirection']"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:apply-templates>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="conditionMountain">
  <xsl:param name="trans"/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='MTNS']"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:apply-templates select="condMoun">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="condMoun">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:if test="position() != 1">
   <xsl:text>, </xsl:text>
  </xsl:if>
  <xsl:if test="locationAndList != ''">
   <xsl:apply-templates select="locationAndList/locationThruList">
    <xsl:with-param name="compassDirDescr" select="$trans/t[@o='compassDirLocation']"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:apply-templates>
   <xsl:if test="MOV != '' or MOVD != ''">
    <xsl:text>,</xsl:text>
   </xsl:if>
  </xsl:if>
  <xsl:if test="MOV != ''">
   <xsl:value-of select="$trans/t[@o='MOV']"/>
   <xsl:apply-templates select="MOV/locationAndList/locationThruList">
    <xsl:with-param name="compassDirDescr" select="$trans/t[@o='compassDirDirection']"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:apply-templates>
  </xsl:if>
  <xsl:if test="MOVD != ''">
   <xsl:value-of select="$trans/t[@o='MOVD']"/>
   <xsl:apply-templates select="MOVD/locationAndList/locationThruList">
    <xsl:with-param name="compassDirDescr" select="$trans/t[@o='compassDirDirection']"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:apply-templates>
  </xsl:if>
  <xsl:if test="locationAndList != '' or MOV != '' or MOVD != ''">
   <xsl:text>: </xsl:text>
  </xsl:if>
  <xsl:value-of select="$trans/condMounType[@o=$this/condMounType/@v]"/>
  <xsl:if test="condMounChange/@v != ''">
   <xsl:value-of select="concat(', ', $trans/condMounChange[@o=$this/condMounChange/@v])"/>
  </xsl:if>
 </xsl:template>

 <xsl:template match="conditionValley">
  <xsl:param name="trans"/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='VAL']"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:apply-templates select="condVall">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="condVall">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:if test="position() != 1">
   <xsl:text>, </xsl:text>
  </xsl:if>
  <xsl:if test="locationAndList != ''">
   <xsl:apply-templates select="locationAndList/locationThruList">
    <xsl:with-param name="compassDirDescr" select="$trans/t[@o='compassDirLocation']"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:apply-templates>
   <xsl:if test="MOV != '' or MOVD != ''">
    <xsl:text>,</xsl:text>
   </xsl:if>
  </xsl:if>
  <xsl:if test="MOV != ''">
   <xsl:value-of select="$trans/t[@o='MOV']"/>
   <xsl:apply-templates select="MOV/locationAndList/locationThruList">
    <xsl:with-param name="compassDirDescr" select="$trans/t[@o='compassDirDirection']"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:apply-templates>
  </xsl:if>
  <xsl:if test="MOVD != ''">
   <xsl:value-of select="$trans/t[@o='MOVD']"/>
   <xsl:apply-templates select="MOVD/locationAndList/locationThruList">
    <xsl:with-param name="compassDirDescr" select="$trans/t[@o='compassDirDirection']"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:apply-templates>
  </xsl:if>
  <xsl:if test="locationAndList != '' or MOV != '' or MOVD != ''">
   <xsl:text>: </xsl:text>
  </xsl:if>
  <xsl:value-of select="$trans/condVallType[@o=$this/condVallType/@v]"/>
  <xsl:if test="condVallChange/@v != ''">
   <xsl:value-of select="concat(', ', $trans/condVallChange[@o=$this/condVallChange/@v])"/>
  </xsl:if>
 </xsl:template>

 <xsl:template match="ERROR">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <td nowrap="1">
   <xsl:value-of select="$trans/hdr[@o='ERROR']"/>
  </td>
  <td colspan="3">
   <xsl:value-of select="$trans/error[@o=$this/descr/@v]"/>
   <br /><xsl:text>&#10;&#9;&#9;&#9;</xsl:text>
   <xsl:value-of select="pos/@v"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

</xsl:stylesheet>
