package metaf2xml::basic;

# copyright (c) metaf2xml 2006
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA

use strict;
use warnings;
use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
require Exporter;

@ISA = qw(Exporter);

use POSIX qw(floor);
use Carp qw(carp);

@EXPORT = qw(
    version_basic
    $FT2M $INHG2HPA
    %weather_descr %weather_types %cloud_types %keywords %phen_loc
    rnd
    printWeather
    printLocations
);

our $FT2M               = 0.3048;
our $INHG2HPA           = 33.86388640341;

our %weather_descr = (
    MI => 'shallow',
    BC => 'patches of',
    PR => 'partial',
    DR => 'low drifting',
    BL => 'blowing',
    SH => 'showers of',
    TS => 'thunderstorm with',
    FZ => 'freezing',
);

our %weather_types = (
    DZ => 'drizzle',
    RA => 'rain',
    SN => 'snow',
    SG => 'snow grains',
    IC => 'ice crystals',
    PL => 'ice pellets',
    GR => 'hail',
    GS => 'small hail and/or snow pellets',
    UP => 'unknown precipitation',
    BR => 'mist',
    FG => 'fog',
    FU => 'smoke',
    VA => 'volcanic ash',
    DU => 'widespread dust',
    SA => 'sand',
    HZ => 'haze',
    PO => 'dust/sand whirls',
    SQ => 'squalls',
    FC => 'funnel cloud',
    SS => 'sandstorm',
    DS => 'duststorm',
    TS => 'thunderstorm',
    SH => 'showers',
);

our %cloud_types = (
    AC     => 'altocumulus',
    ACC    => 'altocumulus castellanus',
    ACSL   => 'altocumulus standing lenticular',
    AS     => 'altostratus',
    CB     => 'cumulonimbus',
    CBMAM  => 'cumulonimbus mammatus',
    CC     => 'cirrocumulus',
    CCSL   => 'cirrocumulus standing lenticular',
    CF     => 'cumulus fractus',
    CI     => 'cirrus',
    CS     => 'cirrostratus',
    CU     => 'cumulus',
    CUFRA  => 'cumulus fractus',
    NS     => 'nimbostratus',
    SAC    => 'stratoaltocumulus',
    SC     => 'stratocumulus',
    SCSL   => 'stratocumulus standing lenticular',
    SF     => 'stratus fractus',
    ST     => 'stratus',
    STFRA  => 'stratus fractus',
    TCU    => 'towering cumulus',
);

our %keywords = (
    '$'     => 'automated system needs maintenance',
    ABV     => 'above',
    AI      => 'AI',
    ALL     => 'all',
    ALQDS   => 'all quadrants',
    ALSTG   => 'altimeter setting',
    ALTM    => 'altimeter',
    AND     => 'and',
    APCH    => 'approach',
    ASOCTD  => 'associated',
    AT      => 'at',
    AURBO   => 'aurea borealis',
    BA      => 'braking action',
    BECMG   => 'becoming:',
    BINOVC  => 'breaks in overcast',
    BLW     => 'below',
    CAVOK   => 'cloud and visibility OK',
    CAVU    =>'clear or scattered clouds and visibility greater than ten miles',
    CHINO   => "sensor not operating:\tsecondary ceiling height indicator",
    CIG     => 'ceiling',
    CIGRAG  => 'ceiling ragged',
    CLD     => 'cloud',
    CONTRAIL => 'contrails',
    CONTRAILS => 'contrails',
    CONS    => 'continuous',
    CVCTV   => 'convective',
    D       => 'down',
    DA      => 'density altitude',
    DATA    => 'data',
    DSNT    => 'in the distance',
    DRY     => 'dry',
    EMBD    => 'embedded',
    EPC     => 'estimated pass closed',
    EPO     => 'estimated pass open',
    ESTMD   => 'estimated',
    FG_BNK  => 'fog bank',
    FGBNK   => 'fog bank',
    FIRST   => 'first',
    FOGGY   => 'foggy',
    FM      => 'from',
    FROIN   => 'frost on the indicator',
    FRQ     => 'frequent',
    FULYR   => 'smoke layer aloft',
    FUOCTY  => 'smoke over city',
    FZRANO  => "sensor to decect freezing rain not operating",
    GOOD    => 'good',
    GRID    => 'grid',
    HZY     => 'hazy',
    ICG     => 'icing',
    INTMT   => 'intermittent',
    IOVC    => 'in overcast',
    ISOL    => 'isolated',
    IR      => 'ice on runway',
    LAST    => 'last',
    LGT     => 'light',
    LOW     => 'low',
    LTG     => 'lightning',
    LSR     => 'loose snow on runway',
    LWR     => 'lower',
    METAR   => 'METeorological Aerodrome Report',
    MISG    => 'missing',
    MOV     => 'moving',
    MOVD    => 'moved',
    MTNS    => 'mountains',
    N       => 'no change',
    NOSIG   => 'no significant change',
    NOSPECI => 'no SPECI reports are taken at this station',
    OAT     => 'outside air temp.',
    OBSCG   => 'obscuring',
    OBSCURED => 'obscured',
    OCNL    => 'occasional',
    OHD     => 'overhead',
    OMTNS   => 'over mountains',
    P       => 'patchy',
    PA      => 'pressure altitude',
   'PAST HR'=> 'past hour',
    PCPN    => 'precipitation',
    PK      => 'peak',
    PNO     => "sensor not operating: tipping bucket rain gauge",
    POOR    => 'poor',
    PRESFR  => "pressure trend: falling rapidly",
    PRESRR  => "pressure trend: rising rapidly",
    PSR     => 'packed snow on runway',
    PWINO   => "sensor to identify present weather not operating",
   'PWR PLNT PLUME' => 'power plant plume',
    QUAD    => 'quadrant',
    RCRNR   => 'runway condition reading not reported',
    RTS     => 'return to service',
    RVRNO   => 'runway visual range should be reported but is missing',
    RWY     => 'runway',
    SANDED  => 'sanded',
    SFC     => 'surface',
    SKY     => 'sky',
    SLP     => 'sea level pressure',
    SLR     => 'slush on runway',
    SPTS    => 'spots',
    SST     => 'sea surface temp.',
    RH      => 'relative humidity',
    TEMPO   => 'temporarily:',
    THN     => 'thin',
    THRU    => 'through',
    TL      => 'till',
    TSNO    => "sensor to decect lightning not operating",
    TWR     => 'tower',
    U       => 'up',
    VAL     => 'valleys',
    VC      => 'in the vicinity',
    VIRGA   => 'virga',
    VISNO   => "sensor not operating:\tsecondary visibility sensor",
    VIS     => 'visibility',
    VRY     => 'very',
    WET     => 'wet',
    WND     => 'wind',
    WNDS    => 'winds',
);

my %comp_dir = (
    N     => 'north',
    E     => 'east',
    S     => 'south',
    W     => 'west',
);

our %phen_loc = (
        N => $comp_dir{N},
      NNE => join('-', @comp_dir{'N', 'N', 'E'}),
       NE => join('-', @comp_dir{'N', 'E'}),
      ENE => join('-', @comp_dir{'E', 'N', 'E'}),
        E => $comp_dir{E},
      ESE => join('-', @comp_dir{'E', 'S', 'E'}),
       SE => join('-', @comp_dir{'S', 'E'}),
      SSE => join('-', @comp_dir{'S', 'S', 'E'}),
        S => $comp_dir{S},
      SSW => join('-', @comp_dir{'S', 'S', 'W'}),
       SW => join('-', @comp_dir{'S', 'W'}),
      WSW => join('-', @comp_dir{'W', 'S', 'W'}),
        W => $comp_dir{W},
      WNW => join('-', @comp_dir{'W', 'N', 'W'}),
       NW => join('-', @comp_dir{'N', 'W'}),
      NNW => join('-', @comp_dir{'N', 'N', 'W'}),
    ALQDS => $keywords{ALQDS},
    OHD   => $keywords{OHD},
);

sub version_basic {
    return 'basic: $Id: basic.pm,v 1.7 2006/08/10 18:36:17 metaf2xml Exp $';
}

sub rnd {
    my ($val, $prec) = @_;
    return $prec * floor(($val / $prec) + 0.5);
}

sub printWeather {
    my ($w, $recent) = @_;
    my ($msg, $int, $vc, $desc, $phen, $intensity, $delim);

    return "(not available)" if exists $w->{notAvailable};
    return "(invalid format: '$w->{invalidFormat}')"
        if exists $w->{invalidFormat};
    return 'nil significant weather' if exists $w->{NSW};

    return 'tornado/water spout'
        if exists $w->{tornado};

    # EXTENSION:
    # allow FZ with (BC|PR)FG (Austria, WMO-No. 306, Vol. II)
    $delim = '';
    if (exists $w->{intensity}) {
        $int = $w->{intensity} eq 'LIGHT' ? '-' : '+';
    } else {
        $int = '';
    }
    $intensity = { ''  =>      defined $recent
                            || exists $w->{inVicinity}
                            || !exists $w->{phenomenon}
                            || join('', @{$w->{phenomenon}}) !~ 'DZ|RA|SN|SG|PL|GR|GS|DS|SS'
                          ? '' :'moderate',
                   '+' => 'heavy',
                   '-' => 'light' }->{$int};
    if (   $intensity
        && (   !exists $w->{descriptor}
            || join('', @{$w->{descriptor}}) !~ 'TS'))
    {
        $msg .= $intensity;
        $delim = ' ';
    }
    if (exists $w->{descriptor}) {
        for (@{$w->{descriptor}}) {
            $msg .= $delim . $weather_descr{$_};
            $delim = ' ';
        }
        if ($intensity && join('', @{$w->{descriptor}}) =~ 'TS') {
            $msg .= $delim . $intensity;
            $delim = ' ';
        }
    }

    for (exists $w->{phenomenon} ? @{$w->{phenomenon}} : ()) {
        $msg .= $delim . $weather_types{$_};
        $delim = ' ';
    }
    $msg .= ' ' . $keywords{VC} if exists $w->{inVicinity};

    $msg =~ s/(showers) of (snow|rain)$/$2 $1/;

    return $msg;
}

sub _printQuadrants {
    my $q = shift;
    my ($delim, $txt);
    $delim = '';
    for (@$q) {
        $txt .= $delim . { 1 => 'first',
                           2 => 'second',
                           3 => 'third',
                           4 => 'forth',
                         }->{$_};
        $delim = ' to ';
    }
    return " $txt quadrant";
}

sub printLocations {
    my $r = shift;
    my ($delim1, $delim2, $txt);

    $delim2  = '';
    for my $l (@$r) {
        $txt .= $delim2;
        $delim2 = ' and';
        $delim1  = '';
        for (@$l) {
            $txt .= $delim1;
            $delim1 = ' through';
            $txt .= ' ' . $keywords{DSNT} if exists $_->{isDistant};
            $txt .= ' ' . $keywords{VC} if exists $_->{inVicinity};
            $txt .= ' ' . $keywords{$_->{locationSpec}}
                if exists $_->{locationSpec};
            $txt .= ' ' . "@keywords{'OBSCG', 'MTNS'}"
                if exists $_->{obscgMtns};
            $txt .= ' ' . $keywords{GRID} if exists $_->{isGrid};
            $txt .= ' ' . $_->{distance} . ' sm' if exists $_->{distance};
            $txt .= ' ' . $phen_loc{$_->{compassDir}}
                if exists $_->{compassDir};
            $txt .= _printQuadrants $_->{quadrant}
                if exists $_->{quadrant};
            $txt .= ' ' . $keywords{QUAD} if exists $_->{isQuadrant};
        }
    }
    return $txt;
}

1;
__END__
